package mo.dataprog.dataStructures;

import mo.dataprog.utilities.Utilities;
import mo.exceptions.InvalidTokenException;

public class Token
{
	
	/**
	 * The type of the Token
	 */
	TokenType tokenType;
	

	/**
	 * The token itself
	 */
	String text;
	
	
	
	/**
	 * Probability of occurrence of token
	 */
	private double probability;
	
	public Token(TokenType _type)
	{
		text = "";
		probability = 0;
		tokenType = _type;
	}
	
	public Token(String _text, TokenType _type)
	{
		text = _text;
		tokenType = _type;
		probability = 0;		
	}
	
	
	public Token (String _text, double _probability) throws InvalidTokenException
	{			
		text = _text;
		tokenType = Utilities.determineTokenType(_text);
		probability = _probability;		
	}
	
	
	public Token (String _text) throws InvalidTokenException
	{			
		text = _text;
		tokenType = TokenType.SpecificType;
		probability = 0;		
	}
	
	
	
	
	public TokenType getTokenType()
	{
		return tokenType;
	}



	public String getText()
	{
		return text;
	}


	public double getProbability()
	{
		return probability;
	}


	public void setProbability(double probability)
	{
		this.probability = probability;
	}
	
	
	
	/**
	 * Overriden method to return text. If the type is SpecificType then the string value is retruned.
	 * Otherwise token Value
	 */	
	@Override
	public String toString()
	{
		//return tokenType == TokenType.SpecificType ? text : tokenType.toString();
		
		return tokenType + "("+ text +")";
	}
	
 

	@Override
	public boolean equals(Object obj)
	{
		boolean ret;
		if (obj instanceof Token)
		{
			Token t = (Token)obj;
			if (t.getTokenType() != TokenType.SpecificType)
				ret = t.getTokenType().equals(this.tokenType);
			else
				ret = t.getText().equals(this.text);
		}
		else
			ret = super.equals(obj);
		
		return ret;
	}
	
	
	
	@Override
	public int hashCode()
	{
		int ret;
		if (this.tokenType != TokenType.SpecificType)
			ret = this.tokenType.hashCode();
		else
			ret = this.text.hashCode();
	
		return ret;
	}

	/**
	 * Important - this methid clears out the text variable
	 * @param tokenType
	 */
	public void setTokenType(TokenType tokenType)
	{
		this.tokenType = tokenType;
		this.text = "";
	}

	public void setText(String text, boolean determineType ) throws InvalidTokenException
	{
		this.text = text;
		if (determineType == true)
		{
			this.tokenType = Utilities.determineTokenType(text);
		}
		else
		{
			this.tokenType = TokenType.SpecificType;
		}
		
	}

}
