package mo.dataprog.dataStructures;

import java.util.ArrayList;
import java.util.Hashtable;
import java.util.Iterator;

import mo.dataprog.utilities.Utilities;
import mo.exceptions.InvalidTokenException;
import cern.jet.stat.*;
/**
 * Class representing an element of the Tree
 * Each element contains reference to the tree itself.
 * @author Administrator
 *
 */


/**
 * Using the COLT open-source library for computing integral value.
 * License is as follows:
 * 
    Packages cern.colt* , cern.jet*, cern.clhep

    Copyright (c) 1999 CERN - European Organization for Nuclear Research.

    Permission to use, copy, modify, distribute and sell this software and its documentation for any purpose is hereby granted without fee, 
    provided that the above copyright notice appear in all copies and that both that copyright notice and this permission notice appear in 
    supporting documentation. CERN makes no representations about the suitability of this software for any purpose. It is provided "as is" 
    without expressed or implied warranty.


	Packages hep.aida.*

    Written by Pavel Binko, Dino Ferrero Merlino, Wolfgang Hoschek, Tony Johnson, Andreas Pfeiffer, and others. Check the FreeHEP home page 
    for more info. Permission to use and/or redistribute this work is granted under the terms of the LGPL License, with the exception that 
    any usage related to military applications is expressly forbidden. The software and documentation made available under the terms of this 
    license are provided with no warranty. 
 */
public class TreeElement
{
	
	private final double alpha = 0.1;
	
	/**
	 * Children of this element
	 */
	ArrayList<TreeElement>		children;
	
	/**
	 * token in this element
	 */
	Token			token;
	
	/**
	 * List of examples that follow current Token
	 */
	ArrayList<ArrayList<String>> examples;	
	
	
	/**
	 * PAttern  represented by the element in the tree
	 */
	ArrayList<Token>	pattern;

	/**
	 * Depth of the element of the tree (root has depth = 0)
	 */
	private int depth;
	
	
	/**
	 * Constructor of the TreeElement (used only for creation of Root)
	 * @param theTree reference to the tree containing this element
	 * @throws InvalidTokenException 
	 */
	public TreeElement() throws InvalidTokenException
	{
		// creation of arrayList with children
		children = new ArrayList<TreeElement>();
		depth = 0;
		
		token = new Token("");
		token.setProbability(1);
	}
	
	
	/**
	 * Construcotr used for regular creation of TreeElements
	 * @param theTree
	 * @param text
	 * @throws InvalidTokenException
	 */
	public TreeElement(String _text, double _probability,int _depth) throws InvalidTokenException
	{		
		this();
		token = new Token(_text,_probability );
		depth =  _depth;
	}
	
	/**
	 * Construcotr used for regular creation of TreeElements
	 * @param theTree
	 * @param text
	 * @throws InvalidTokenException
	 */
	public TreeElement(TokenType _type, double _probability,int _depth) throws InvalidTokenException
	{		
		this();
		token = new Token(_type);
		token.setProbability(_probability);
		depth =  _depth;
	}
	
	
	
	/**
	 * Method responsible for creation of children for this Tree Element
	 * @throws InvalidTokenException 
	 * @throws InvalidTokenException 
	 */
	public void CreateChildren(Hashtable<Token, Double> initialProbabilites, int actDepth) throws InvalidTokenException
	{
			
		// iterator
		Iterator<ArrayList<String>> it = examples.iterator();
		
		// temporary variables 
		TreeElement newElement;
		ArrayList<String> current;
		
		
		//variables used to perform calculations during loop		
		String currentStr;
		TokenType currTokenType;
		Token temp = new Token("");
	
		ArrayList<ArrayList<String>> currentExamples;
		
		// variable for storing current token position in consecutive arraylists
		int currListIndex = 0;
		
		// variable for storing current arraylist position in list of lists
		int currPositionInExamples = actDepth;
		
			
			
		// we iterate through list of all examples
		it = examples.iterator();		
		// we iterate through all examples and create new child for each token at current position in examples
		currListIndex = 0;
		while (it.hasNext())
		{			
			current = it.next();	
			
			if (current.size() > currPositionInExamples) // if current list of examples is long enough 
			{
				// if one of the elements is not well formed, then this should not crash the application
				try
				{
					// initialization of temporary variables
					currentStr = current.get(currPositionInExamples); // actual text					
					currTokenType = Utilities.determineTokenType(currentStr);  // determine the token type
					currentExamples = this.InitExamples(examples, currPositionInExamples , currTokenType, currentStr); // init examples
					
					// we will iterate through all token types in examples - at first the general Types, then specific ones
					ArrayList<TokenType> listForCurrExample = Utilities.GetMoreGeneralTokenTypes(currTokenType);					
					listForCurrExample.add(currTokenType);
					
					// for each tokenType at next position in examples
					for (TokenType type : listForCurrExample)
					{
						// we do not care about tokens that are already contained
						if (ListAlreadyContainsToken(this.children,type))
							continue;
												
						temp = new Token(type);
						
						if (IsSignificant(currentExamples.size(),this.examples.size(),initialProbabilites.get(temp) * this.token.getProbability()))// actualProbabilities[currListIndex] * tokenInitialProbability))
						{							
							newElement = new TreeElement(type, initialProbabilites.get(temp) * this.token.getProbability(),actDepth+1);							
							newElement.setExamples(currentExamples);
							
							ArrayList<Token> childPattern;							
							// newelement's pattern is current pattern concatenated with token
							if (this.pattern == null)
							{
								childPattern = new ArrayList<Token>();
							}
							else
							{
								childPattern = new ArrayList<Token>(this.pattern);	
							}
							
							// concatenation of patterns
							childPattern.add(new Token(
													newElement.getToken().getTokenType()));
													//newElement.getToken().getText()));
							newElement.setPattern(childPattern);
							this.children.add(newElement);
						}							
					}
					
					// specific Type
					if(!ListAlreadyContainsToken(this.children, currentStr))
					{
						currentExamples = this.InitExamples(examples, currPositionInExamples, TokenType.SpecificType, currentStr); // init examples
						temp = new Token(currentStr);					
						
						if (IsSignificant(currentExamples.size(),this.examples.size(),initialProbabilites.get(temp) * this.token.getProbability()))// actualProbabilities[currListIndex] * tokenInitialProbability))
						{
							newElement = new TreeElement(currentStr, initialProbabilites.get(temp) * this.token.getProbability(),actDepth+1);
							
							newElement.setExamples(currentExamples);
							
							ArrayList<Token> childPattern;
							
							// newelement's pattern is current pattern concatenated with token
							if (this.pattern == null)
							{
								childPattern = new ArrayList<Token>();
							}
							else
							{
								childPattern = new ArrayList<Token>(this.pattern);	
							}
							
							// concatenation of patterns
							childPattern.add(new Token(
													//newElement.getToken().getTokenType(),
													newElement.getToken().getText()));
							newElement.setPattern(childPattern);
							this.children.add(newElement);
						}
					}					
				} 
				catch (InvalidTokenException e)
				{
					// TODO Auto-generated catch block
					e.printStackTrace();
				}			
				
			} // if
			currListIndex++;
		} // while (it.hasNext())		
		//	currPositionInExamples++;
	//	}// while (currposition < length)
		
	} // end method


	private boolean ListAlreadyContainsToken(ArrayList<TreeElement> list, TokenType type)
	{
		for (TreeElement element : list)
		{
			if (element.getToken().getTokenType().equals(type))
				return true;				
		}
		return false;
	}

	
	private boolean ListAlreadyContainsToken(ArrayList<TreeElement> list, String text)
	{
		for (TreeElement element : list)
		{
			if (element.getToken().getText().equals(text))
				return true;				
		}
		return false;
	}


	private boolean IsSignificant(int childNodeCount,int parentNodeCount, double probability)
	{
		double computedProbability = 0;
		// mean, variance and x
		double	mean,
				variance;
		
		
		//if (probability == 1)
			//return false;
		
		
		mean = parentNodeCount * probability;
		
		variance = mean*(1-probability);
		
	
			
		computedProbability  =  Probability.normal(mean, variance, childNodeCount - 1);
		
		// class from COLT calculates integral on the interval from minus infinity  to x.
		// we areinterested in value from x to infinity
		// since infinity in computers is represented by higest possible number, then we
		// will compute integral on the interval from minus infinity to int.MAX_VALUE
		// and then we will substract from it value of computeedIntegral
		double wholeInterval = Probability.normal(mean, variance, Integer.MAX_VALUE);
		
		double inversed = wholeInterval - computedProbability;
		
		boolean ret = inversed  < alpha;
		
		//System.out.println(newNodeCount + " " + no2 + " " +  probability + " " + ret + " " +inversed);
		return ret;
		
		
	
	}


	
	public void PruneNodes()
	{	
		Iterator<TreeElement> it = this.children.iterator();
		
		
		TreeElement curr;
				
		// for every child
		while (it.hasNext())
		{
			curr = it.next();
			Iterator<TreeElement> itSibling = this.children.iterator();
			// for every sibiling of that child
			TreeElement child;
			while(itSibling.hasNext())
			{
				child = itSibling.next();
				// we omit ourself
				if (child == curr)
					continue;
				
				// if sibling's pattern is contained in current child's pattern
				if (IsContained(child.getPattern(), curr.getPattern()))
				{
					int N = curr.getExamples().size() - child.getExamples().size();
					if (!IsSignificant(N, this.examples.size() ,curr.getToken().getProbability()))
					{
						it.remove();
						it = this.children.iterator();
						break; // jump out if the 'sibling' loop
					}
					else
					{
						itSibling.remove();
						it = this.children.iterator();
					}
				}
			}
			
			
		}
	}
	
	/**
	 * This method determines whether "patternContained" is contained in "patterContaining"
	 */
	private boolean IsContained(ArrayList<Token> patternContained,	ArrayList<Token> patternContaining)
	{
		if (patternContained.size() > patternContaining.size())
			throw new IllegalArgumentException("Contained pattern cannot be longer than containing pattern!");
		
		boolean ret = true;
		int smallerSize = patternContained.size();
		for (int i = 0; i < smallerSize ; i++)
		{
			ret &= Utilities.CheckIfFirstTokenIsMoreGeneral(patternContaining.get(i).getTokenType(), patternContained.get(i).getTokenType());
		}
		return ret;
		
	/*	boolean ret = true;
		int smallerSize = patternContained.size();
		
		for (int i = 0; i < smallerSize; i++)
		{
			ret &= (patternContained.get(i).equals(patternContaining.get(i)));
		}
		
		return ret;*/
	}


	/**
	 * Method for initiating list of examples of element by list of examples that follow current token (detailed description inside method)
	 * @param examples
	 * @param currPosition
	 * @return
	 * @throws InvalidTokenException 
	 */
	private ArrayList<ArrayList<String>> InitExamples(ArrayList<ArrayList<String>> examples, int positionTocheck, TokenType T, String text) throws InvalidTokenException
	{
		// One of the steps of DataProg algorithm states that each children should have list of examples
		// initalized by list of all examples that are followed by this Token
		// This means that we have to make ArrayList if the same size, but each element in the list
		// should be part of initial examples list.
		
		ArrayList<ArrayList<String>> ret = new ArrayList<ArrayList<String>>();
		
		Iterator<ArrayList<String>> it = examples.iterator();
		ArrayList<String> curr;
		
		while (it.hasNext())
		{
			curr = it.next();
			if (curr.size() <= positionTocheck)
				continue;
			
			if (T == TokenType.SpecificType)
			{
				if (curr.get(positionTocheck).equals(text))
				{
					ret.add(curr);
				}
			}
			else
			{
				if (Utilities.determineTokenType(curr.get(positionTocheck)) == T)
				{
					ret.add(curr);
				}
			}			
		}
		
		
		return ret;
		
	/*	// we create copy of arrayList (method clone is very tricky, so we try to avoid it)
		ArrayList<ArrayList<String>> ret = new ArrayList<ArrayList<String>>(examples);
		
		
		// we iterate through list and remove elements at position prior to currPosition
				
		ArrayList<String> current;
		
		for (int i =0 ; i < examples.size() ; i++)
		{
			current = ret.get(i);
			current = new ArrayList<String>(current.subList(currPosition, current.size()));
			ret.set(i,current);			
		}
			
		
		
		// TODO Auto-generated method stub
		return ret;*/
	}


	
	
	
	public Token getToken()
	{
		return token;
	}


	public ArrayList<Token> getPattern()
	{
		return pattern;
	}


	public void setPattern(ArrayList<Token> pattern)
	{
		this.pattern = pattern;
	}
	

	public ArrayList<ArrayList<String>> getExamples()
	{
		return examples;
	}


	public void setExamples(ArrayList<ArrayList<String>> examples)
	{
		this.examples = examples;
	}


	public ArrayList<TreeElement> getChildren()
	{
		return children;
	}


	public int getDepth()
	{
		return depth;
	}
	
	@Override
	public String toString()
	{
		// TODO Auto-generated method stub
		return token.toString();
	}

	

}
