package mo.dataprog.utilities;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Set;
import java.util.Map.Entry;

import mo.dataprog.dataStructures.Token;
import mo.dataprog.dataStructures.TokenType;
import mo.exceptions.InvalidTokenException;

public class PatternSearcher
{
	private final String googleQueryString = "http://www.google.pl/search?q=";
	
	private final String hrefString = "href=\"";
	
	Hashtable<String, Integer>	patternCount;
	
	public static void main(String args[])
	{
		ArrayList<Token> pattern = new ArrayList<Token>();
		
		pattern.add(new Token("ul", TokenType.SpecificType));
		pattern.add(new Token(".", TokenType.SpecificType));
		pattern.add(new Token(TokenType.Upper));
		pattern.add(new Token(TokenType.Number));
		
		try
		{
			PatternSearcher searcher = new PatternSearcher("Honoratka+Restaurant+Warsaw", pattern);
			System.out.println(searcher.getMax());
		} 
		
		catch (IOException e)
		{
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (Exception e)
		{
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
	}
	
	public PatternSearcher(String	query, ArrayList<Token> pattern) throws IOException, Exception
	{
		WebPageReader reader = new WebPageReader(googleQueryString + query);
		
		// we are intersted in pure content, so that we can take advantage of <a href ...> tags
		String content = reader.getPureContent();
		
		int indexOfHref = content.indexOf(hrefString);
		int beginIndex;
		String newUrl;
		
		patternCount = new Hashtable<String, Integer>();
		
		while (indexOfHref > 0)
		{
			beginIndex = indexOfHref + hrefString.length();
			
			newUrl  = content.substring( beginIndex, content.indexOf("\"", beginIndex+1));
						
			try
			{
				WebPageReader webPageReader = new WebPageReader(newUrl);
				
				String []extracted = this.ExtractPattern(webPageReader.getNoHTMLContent(), pattern);
				if (extracted != null)
				{
					for (int i = 0; i < extracted.length ; i++)
					{
						Integer value = patternCount.get(extracted[i]);
					
						if (value == null)
							value = 0;
					
						value++;
						
						this.patternCount.put(extracted[i], value);
					}
				}
			} 
			catch (MalformedURLException e)
			{
			//do nothing
			}
			catch (InvalidTokenException e)
			{
				// do nothing
			}
			catch (IOException e)
			{
				// TODO Auto-generated catch block
				e.printStackTrace();
			} 
			catch (Exception e)
			{
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
			
			indexOfHref = content.indexOf(hrefString, indexOfHref + 1);
		}
		
	}
	
	
	public String getMax()
	{
		String ret = null;
		int max = -1;
		
		Set<Entry<String, Integer>> entrySet = patternCount.entrySet();
		Iterator<Entry<String, Integer>> it = entrySet.iterator();
				
		Entry<String, Integer> entry;
		while (it.hasNext())
		{
			entry = it.next();
			System.out.println(entry.getKey() + ";" + entry.getValue());
			
			if (entry.getValue() > max)
			{
				max= entry.getValue();
				ret = entry.getKey();
			}
		}
		
		
		
		return ret;
	}
	
	
	
	private String[] ExtractPattern(String noHTMLContent, ArrayList<Token> pattern) throws InvalidTokenException
	{		
		ArrayList<String> ret = new ArrayList<String>();
		int patternMatched = 0;
		String token;
		java.util.StringTokenizer tokenizer = new java.util.StringTokenizer(noHTMLContent);
		String foundString ="";
		
		while (tokenizer.hasMoreTokens())
		{
			token = tokenizer.nextToken();
			if (pattern.get(patternMatched).getTokenType() == TokenType.SpecificType)
			{
				if (token.equals(pattern.get(patternMatched).getText()))
				{
					patternMatched++;	
					foundString += token;
					foundString += " ";
				}
				else					
				{
					patternMatched = 0;
					foundString = "";
				}
			}
			else if (Utilities.determineTokenType(token) == pattern.get(patternMatched).getTokenType())
			{
				patternMatched++;	
				foundString += token;
				foundString += " ";
			}
			else
			{
				patternMatched = 0;
				foundString = "";
			}
			
			if (patternMatched == pattern.size())
			{
				ret.add(new String(foundString));
				patternMatched = 0;
				foundString = "";
			}
			
		}
		
		String []returned = new String[ret.size()];
		
		return (String [])ret.toArray(returned);
	}

	public Hashtable<String, Integer> getPatternCount()
	{
		return patternCount;
	}
}
