package mo.dataprog.utilities;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.net.URLConnection;

import mo.dataprog.utilities.Utilities;

/**
 * Class for handling WebPage reading,
 * and providing contents on clear HTML format or with removed HTML tags
 * or after splitting punctuations from tokens
 * @author Administrator
 *
 */
public class WebPageReader
{
	//private String url;
	
	private String pureContent;
	
	private String noHTMLContent;
	
	public WebPageReader()
	{
		
		
	}
	
	/**
	 * This constructor tries to read the url specified as an argument 
	 * @param url WebPage to Analyze
	 * @throws IOException  in case of malforedURL, or unreadable Stream
	 */
	public WebPageReader(String _url) throws IOException, Exception
	{
		URLConnection conn = (new URL(_url)).openConnection();
		conn.setRequestProperty("User-Agent",""); 
		
		BufferedReader reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
		
		StringBuilder sb = new StringBuilder();
		String line = reader.readLine();
		
		while (line != null)
		{
			sb.append(line);
			line = reader.readLine();
		}
		
		pureContent 	= sb.toString();
		noHTMLContent	= this.RemoveHTMLContent();
		//url 			= _url;
	}
	
	
	private String RemoveHTMLContent() throws Exception
	{
		if (pureContent == null)
			throw new Exception("No content");
		
		// we create instance of stringbuilder class based on pureContent
		StringBuilder sb = new StringBuilder(pureContent);
		
		// fist of all we delete everything from the beginning until the <body> tag
		
		int bodyIndex = sb.indexOf("<body");
		if (bodyIndex == -1)
		{
			// we have not found <body> tag, but it is possible 
			// that uppercase letters were used, so we check that possibility
			bodyIndex = sb.indexOf("<BODY");
			if (bodyIndex == -1)
			{
				// if still we cannot locate index of <body> tag, then it means
				// that someone used mixed-case characters (which is highly irresponsible)
				throw new Exception("Could not locate <body> tag!");
			}
		}
		// if we reach this point, then we have successfully found <body> tag, so we can delete everything before
		sb.delete(0,bodyIndex);
		
		
		// we check for the first occurence of '<' sign (start of every HTML tag)
		int ltIndex = pureContent.indexOf('<');
		
		// while there exists any open HTML tag
		while (ltIndex >= 0)
		{
			// we search for closing of this tag
			int gtIndex = sb.indexOf(">", ltIndex +1);
			
			// if there does not exist ending tag - then document is corrupted
			if (gtIndex < 0)
				throw new Exception("Not well-formed HTML!");

			// since we delete tags, we have to provide that words which were split by  tags
			// don't get 'glued' and become one word - we check if the character previous to
			// found opening tag is a space; If not we insert space in that place
			// we of course remember to increase positions of indices of tags 
			if (ltIndex > 0 && sb.charAt(ltIndex - 1) != ' ')
			{
				sb.insert(ltIndex, " ");
				ltIndex++;
				gtIndex++;
			}
			// we delete the whole contents of tag 
			sb.delete(ltIndex,gtIndex +1);
			
			// we initialize local variable, so it is useful in next loop case
			ltIndex = sb.indexOf("<");
		}
		
		
		// we replace all &nbsp; sequences by spaces
		// we also replace all &lt; by < and &gt; by >
		// in fact there is rather large number of special character sequences,
		// which is interpreted by browsers in variuos ways - nevertheless there is no need
		// to handle those characters
		String temp = sb.toString();
		temp = temp.replaceAll("&nbsp;", " ");
		temp = temp.replaceAll("&lt;", "<");
		temp = temp.replaceAll("&gt;", ">");
		
		// TODO: decide whether it is a good approach  - remove all special characters:
		// this is a regex - beginning with &, then any sequence of non-whitespace characters
		// ended by sign ;
		temp = temp.replaceAll("&\\S*;", "");

		// we also split text characters from punctuation marks
		temp = Utilities.SplitTokensFromPunct(temp);
		
		// now we ensure that there are no duplicate white-space characters		
		temp = temp.replaceAll("\\s{2,}", " ");
		
		return temp;
	}

	public String getPureContent()
	{
		return pureContent;
	}

	public String getNoHTMLContent()
	{
		return noHTMLContent;
	}
}
