package semfly.agents;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class describes Agent, it has its nickname, 
 * name of the class that implements it and input parameters.
 */
public class AgentInfo 
{
	/**
	 * Agent nickname.
	 */
	protected String nickname;
	
	/**
	 * Name of the class that implements it.
	 */
	protected String className;
	
	/**
	 * Input Agent parameters.
	 */
	protected Object[] params;
	
	/**
	 * Creates Agent.
	 * @param nickname Agent nickname.
	 * @param className Name of the class that implements an Agent.
	 */
	public AgentInfo(String nickname, String className) 
	{
		setNickname(nickname);
		setClassName(className);
	}

	/**
	 * Creates Agent.
	 * @param nickname Agent nickname.
	 * @param className Name of the class that implements an Agent.
	 * @param parmas Input Agent parameters.
	 */
	public AgentInfo(String nickname, String className, Object[] params)
	{
		this(nickname, className);
		setParams(params);
	}
	
	/**
	 * Returns the name of the class that implements this Agent.
	 * @return Name of the class that implements this Agent.
	 */
	public String getClassName()
	{
		return className;
	}
	
	/**
	 * Sets the name of the class that implements this Agent.
	 * @param className Name of the class that implements this Agent. 
	 */
	public void setClassName(String className)
	{
		this.className = className;
	}
	
	/**
	 * Returns Agent's nickname.
	 * @return Agent's nickname.
	 */
	public String getNickname()
	{
		return nickname;
	}
	
	/**
	 * Sets Agent's nickname.
	 * @param nickname Nickname to set.
	 */
	public void setNickname(String nickname)
	{
		this.nickname = nickname;
	}
	
	/**
	 * Returns Agent's input parameters.
	 * @return Agent's input parameters.
	 */
	public Object[] getParams()
	{
		return params;
	}
	
	/**
	 * Sets Agent's input parameters.
	 * @param params Agent's input parameters.
	 */
	public void setParams(Object[] params)
	{
		this.params = params;
	}
}
