package semfly.agents;

import semfly.agents.behaviours.AirportsCodesLoader;
import semfly.log.LogWriter;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This agent is responsible for scraping info about all airports of 
 * the world. Info that it is looking for is described by an Airport ontology 
 * (visit http://www.daml.org/2001/10/html/airport-ont for details). 
 * 
 * I had some difficulties to find a web source that owned all necessary data. 
 * The problem was with two properties: IATA code and ICAO code. If a web site 
 * has an IATA code it doesn't have an ICAO code and vice-versa. 
 * So, at the beginning wrapper loads IATA codes from 
 * http://www.world-airport-codes.com and then all necessary details are scraped 
 * from http://www.airrouting.com/content/airportloc.html. 
 */
public class AirportsInfoWrapper extends WrapperAgent
{
	/**
	 * Constructor.
	 */
	public AirportsInfoWrapper()
	{
		super();
	}

	/**
	 * Agent initialization. Adds a behaviour responsible for loading 
	 * Airports' codes (AirportsCodesLoader).
	 * 
	 * @see jade.core.Agent#setup()
	 */
	protected void setup() 
	{
		super.setup();
		
		addBusinessSubBehaviour(new AirportsCodesLoader(this));
	}
	
	/**
	 * Does cleaning before agent death.
	 * Deregisters Agent from DF service.
	 */
	protected void takeDown()
	{
		 super.takeDown();
		 
		 LogWriter.writeError2Log("Number of visited airports: " + 
		         getNumberOfVisitedPages());
		 System.out.println("Number of visited airports: " + 
		         getNumberOfVisitedPages());
	}
}
