package semfly.agents;

import semfly.onto.jade.IndexToken;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This interface should be implemented by all agents who are owners of
 * Tokens Priority Queue.
 * 
 * Coordinator Agent implements it
 * and
 * Tester Agent implement it for testing purposes.
 */
public interface ITPQOwner
{
    /**
     * Retrieves and removes a token with the highest priority from TPQ.
     * @return Token with the highest priority.
     */
    public IndexToken poolIndexToken();
    
    /**
     * Returns number of tokens (IndexToken) in TPQ.
     * @return Number of tokens.
     */
    public int getNumberOfTokens();
    
    /**
     * Checks if there are any tokens in TPQ.
     * @return True - there is at least one token in TPQ, otherwise False.
     */
    public boolean hasIndexTokens();
    
    /**
     * Adds the token given to TPQ.
     * @param token Token to be added.
     */
    public void addIndexToken2TPQ(IndexToken token);
}
