package semfly.agents;

import semfly.agents.behaviours.MarriottLocationsLoader;
import semfly.log.LogWriter;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This agent is responsible for scraping data about Marriot Hotels.
 * Info that he is looking for is described by an Hotel ontology. 
 */
public class MarriottHotelsWrapper extends WrapperAgent
{

    /**
     * Constructor.
     */
    public MarriottHotelsWrapper()
    {
        super();
    }
    
    /**
	 * Agent initialization.
	 * Adds a subbehaviour (of MarriottLocationsLoader type) to Agent's 
	 * main behaviour that is responsible for loading locations of Marriott
	 * hotels.
	 * 
	 * @see jade.core.Agent#setup()
	 */
	protected void setup() 
	{
		super.setup();
		
		addBusinessSubBehaviour(new MarriottLocationsLoader(this));
	}
	
	/**
	 * Does cleaning before agent death.
	 * Deregisters Agent from DF service.
	 */
	protected void takeDown()
	{
		 super.takeDown();
		 
		 LogWriter.writeError2Log("Number of visited Marriott Hotels: " + 
		         getNumberOfVisitedPages());
		 System.out.println("Number of visited Marriott Hotels: " + 
		         getNumberOfVisitedPages());
	}
}
