package semfly.agents;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class describes a Wrapper Agent, it extends AgentInfo class.
 */
public class WrapperAgentInfo extends AgentInfo implements Comparable
{
    /**
     * Time interval after which an Agent of this type should be 
     * created once again.
     */
	protected long timestamp;
	
	/**
	 * Constructor.
	 * @param nickname Agent's nickname.
	 * @param className Class that implements this Agent.
	 */
	public WrapperAgentInfo(String nickname, String className)
	{
		super(nickname, className);
		setTimestamp(0);
	}

	/**
	 * Constructor.
	 * @param nickname Agent's nickname.
	 * @param className Class that implements this Agent.
	 * @param params Agent's input parameters.
	 */
	public WrapperAgentInfo(String nickname, String className, Object[] params)
	{
		super(nickname, className, params);
		setTimestamp(0);
	}
	
	/**
	 * Constructor.
	 * @param nickname Agent's nickname.
	 * @param className Class that implements this Agent.
	 * @param params Agent's input parameters.
	 * @param timestamp
	 */
	public WrapperAgentInfo(String nickname, String className, Object[] params,
							long timest)
	{
		super(nickname, className, params);
		setTimestamp(timest);
	}

	/**
	 * Compares Agent's descriptions. This comparison is based on time interval
	 * after which an Agent of this type should be created once again.
	 * @param o Object to compare with.
	 * 
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	public int compareTo(Object o)
	{
		if (o instanceof WrapperAgentInfo)
		{
			long timest = ((WrapperAgentInfo)o).timestamp;
			
			if (timestamp > timest) return 1;
			if (timestamp == timest) return 0;
			return -1;
		}
		
		return 0;
	}
	
	/**
	 * @return Returns time interval after which an Agent of this type 
	 * should be created once again.
	 */
	public long getTimestamp()
	{
		return timestamp;
	}
	
	/**
	 * Sets time interval after which an Agent of this type 
	 * should be created once again.
	 * @param time The time to be set.
	 */
	public void setTimestamp(long timest)
	{
		this.timestamp = timest;
	}
}
