package semfly.agents.behaviours;

import semfly.agents.IndexingAgent;
import semfly.agents.WrapperAgent;
import semfly.globals.CCSVocabulary;
import semfly.globals.DFAdapter;
import semfly.log.LogWriter;
import jade.core.AID;
import jade.core.Agent;
import jade.lang.acl.ACLMessage;
/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for killing Indexing Agents and Wrapper Agents
 * at system shutdown.
 */
public class AgentsKiller
{
    /**
     * Number of tries to kill all agents.
     */
    private final int noTries2Kill = 3;
    
    /**
     * Tells a sleeping time between killing tries.
     */
    private final int AWhile = 10000;
    
    /**
	 * Agent who's using this class.
	 */
	private Agent myAgent;
    
    private AID[] workingAgents;
    
    public AgentsKiller(Agent owner)
    {
        myAgent = owner;
    }
    
    /**
     * Tries to kill all working agents (IAs and WAs).
     */
    public void run()
    {
        for (int i = 0; i < noTries2Kill; i++)
        {
            findWorkingAgents();
            if (workingAgents.length == 0) break;
            
            sendOrders2Die();
            sleepForAWhile();
        }
        
        sleepForAWhile();
        findWorkingAgents();
        if (workingAgents.length > 0) saveWorkingAgents2Log();
    }
    
    /**
     * Sends order to die to all working agents.
     */
    public void sendOrders2Die()
    {
        ACLMessage msg = new ACLMessage(ACLMessage.REQUEST);
  		
	    for (int i = 0; i < workingAgents.length; i++)
	    {
  			msg.addReceiver(workingAgents[i]);
	    }
	    
	    msg.setContent(CCSVocabulary.ORDER_2_DIE);
	    myAgent.send(msg);
    }
    
    /**
     * Finds all working agents, found agents are saved in "workingAgents"
     * array.
     */
    private void findWorkingAgents()
    {
        DFAdapter searcher = DFAdapter.getInstance();
		
        AID[] wrappers = searcher.searchDF(myAgent, WrapperAgent.ServiceType);
        AID[] indexers = searcher.searchDF(myAgent, IndexingAgent.ServiceType);
        
        workingAgents = new AID[wrappers.length + indexers.length];
        for (int i = 0; i < wrappers.length; i++)
            workingAgents[i] = wrappers[i];
        for (int i = wrappers.length, j = 0; j < indexers.length; i++, j++)
            workingAgents[i] = indexers[j];
    }
    
    /**
     * Saves info about working agents to the CCS log.
     */
    private void saveWorkingAgents2Log()
    {
        for (int i = 0; i < workingAgents.length; i++)
	    {
            LogWriter.writeError2Log("Agent did not die: " + workingAgents[i]);
	    }
    }
    
    private void sleepForAWhile()
    {
        try
        {
            Thread.sleep(AWhile);
        }
        catch (InterruptedException ex){}
    }
}
