package semfly.agents.behaviours;

import org.w3c.dom.Document;
import semfly.exceptions.WebSourceParseException;
import jade.core.Agent;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This behaviour parses the given DOM objects with airports info by using Jaxen 
 * and then creates appropriate token to be send to the Coordinator
 * (by using WrapperSender bahaviour).
 */
public class AirportsInfoProcessor extends ResourceProcessor
{
    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private AirportsInfoProcessorBL airProcessor = null;
	
	/**
	 * Constructor.
	 * @param owner Agent - owner of this behaviour.
	 * @param airportsDetails Web pages with airports details.
	 */
	public AirportsInfoProcessor(Agent owner, Document[] airportsDetails)
	{
		super(owner);
		
		airProcessor = new AirportsInfoProcessorBL(owner, airportsDetails);
	}
	
	/**
	 * Processes pages with airports details. Extracts an importane info about
	 * airports and creates Jena Model.
	 * 
	 * @see semfly.agents.behaviours.ResourceProcessor#processResource()
	 */
	protected void processResource() throws WebSourceParseException 
	{
		model = airProcessor.processResource();
	}
}
