package semfly.agents.behaviours;

import jade.core.Agent;
import jade.core.behaviours.SequentialBehaviour;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class represents business bahaviour 
 * (extends <code>SequentialBehaviour</code>).
 * After the current subbehaviour of this behaviour is executed 
 * it's immediatly removed from the subbehaviours list.
 */
public class BusinessBehaviour extends SequentialBehaviour
{ 
    /**
     * Constructor.
     */
    public BusinessBehaviour()
    {
        super();
    }

    /**
     * Constructor.
     * @param owner Agent - owner of this behaviour.
     */
    public BusinessBehaviour(Agent owner)
    {
        super(owner);
    }

    /** 
     * Sequential policy for children behaviours scheduling. 
     * This method schedules children behaviours one at a time.
     * If current behaviour is done this method removes it from 
     * sub bahaviours list.
     * 
     * @see jade.core.behaviours.CompositeBehaviour#scheduleNext(boolean, int)
     */
    protected void scheduleNext(boolean currentDone, int currentResult)
    {
        if (currentDone)
        {
            removeCurrentBehaviour();
            scheduleFirst();
        }
    }
    
    /**
     * Check whether this <code>BusinessBehaviour</code> must terminate.
     * @return True when the last child has terminated, False otherwise.
     * 
     * @see jade.core.behaviours.CompositeBehaviour#checkTermination
	*/
	protected boolean checkTermination(boolean currentDone, int currentResult) 
	{
	 	return (currentDone && getChildren().isEmpty());
	}
    
    /**
     * Removes current subbehaviour.
     */
    private void removeCurrentBehaviour()
    {
        super.removeSubBehaviour(super.getCurrent());
    }
    
    /**
     * Does nothing. Don't call this method.
     */
    public void skipNext() 
    {
    }
}
