package semfly.agents.behaviours;

import semfly.agents.CoordinatorAgent;
import semfly.exceptions.ExceptionManager;
import semfly.globals.CCSVocabulary;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.domain.FIPAAgentManagement.NotUnderstoodException;
import jade.domain.FIPAAgentManagement.RefuseException;
import jade.lang.acl.ACLMessage;
import jade.lang.acl.MessageTemplate;
import jade.proto.SimpleAchieveREResponder;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 * 
 * This class is responsible for receiving messages from GUI Agent.
 */
public class CoordinatorGUIReceiver extends SimpleAchieveREResponder
{

    /**
	 * Constructor.
	 * @param agent Agent - owner of this behaviour.
	 * @param msgTemplate Message tempale for received messages.
	 */
    public CoordinatorGUIReceiver(Agent agent, MessageTemplate msgTemplate)
    {
        super(agent, msgTemplate);
    }

    /**
	 * Constructor.
	 * @param agent Agent - owner of this behaviour.
	 * @param msgTemplate Message tempale for received messages.
	 * @param ds Agent's data store.
	 */
    public CoordinatorGUIReceiver(Agent agent, MessageTemplate msgTemplate,
            DataStore ds)
    {
        super(agent, msgTemplate, ds);
    }

    /**
	 * Prepares response for the received ASL message.
	 */
	protected ACLMessage prepareResponse(ACLMessage request) 
		throws NotUnderstoodException, RefuseException 
	{
	    ACLMessage response = request.createReply();
	    String order = request.getContent();
	    if (order.equals(CCSVocabulary.ORDER_2_DIE))
	        response.setPerformative(ACLMessage.AGREE);
	    else
	        response.setPerformative(ACLMessage.NOT_UNDERSTOOD);
		
		return response;
	}
	
	/**
	 * Prepares result notification for the requested action.
	 */
	protected ACLMessage prepareResultNotification(ACLMessage request,
            ACLMessage prevResponse) throws FailureException 
	{
	    ACLMessage response = request.createReply();
		
		try
		{
		    String order = request.getContent();
		    if (order.equals(CCSVocabulary.ORDER_2_DIE))
		        killAgents();
		   
		    response.setPerformative(ACLMessage.INFORM);
		    response.setContent(CCSVocabulary.CLOSE_WINDOW);
		    ((CoordinatorAgent)myAgent).commitSuicide();
			return response;
		}
		catch (Exception ex)
		{
			ExceptionManager.publish(ex);
		}
		
		response.setPerformative(ACLMessage.FAILURE);
		return response;
	}
	
	/**
	 * Kills all working Indexing Agents and Wrapper Agents. Start killing
	 * from Indexing Agents.
	 */
	private void killAgents()
	{
	    AgentsKiller killer = new AgentsKiller(myAgent);
	    killer.run();
	}
}
