package semfly.agents.behaviours;

import semfly.agents.CoordinatorAgent;
import semfly.exceptions.ExceptionManager;
import jade.core.behaviours.CyclicBehaviour;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class represents a scheduler of the Coordinator Agent.
 * This class is responsible for:
 * 1. starting Indexing Agents at CCS start-up
 * 2. starting Wrapper Agents at CCS start-up and starting them in appropriate
 * 		time (after appropriate intervales)
 */
public class CoordinatorScheduler extends CyclicBehaviour
{
    private CoordinatorSchedulerBL scheduler;
    private boolean error = false;
	
	public CoordinatorScheduler(CoordinatorAgent coordinatorAgent) 
	{
	    assert coordinatorAgent != null;
	    
	    scheduler = new CoordinatorSchedulerBL(coordinatorAgent);
	    scheduler.setPlatform(coordinatorAgent.getContainerController());
	}

	/**
	 * Starts Agents (IndexingAgents and WrapperAgents) in proper time.
	 */
	public void action() 
	{  
	    if (error) return;
	    
	    try
	    {
			if (!scheduler.isActed())
			    scheduler.actForTheFirstTime();
			else
			    scheduler.actForTheNextTime();
	    }
	    catch (Exception ex)
	    {
	        ExceptionManager.publish(ex);
	        error = true;
	    }
	}
}
