package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.agents.WrapperAgent;
import semfly.dto.HotelDocument;
import semfly.dto.HotelLocation;
import semfly.exceptions.ExceptionManager;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class represents a Behaviour that is to load codes 
 * of all Hilton Hotels. 
 */
public class HiltonHotelCodesLoader extends ResourceLoader
{
    private HiltonHotelCodesLoaderBL hiltonLoader;
    
    public HiltonHotelCodesLoader(Agent agent, HotelLocation[] hotelsLocations)
    {
        super(agent);
        
        hiltonLoader = new HiltonHotelCodesLoaderBL(agent, hotelsLocations);
    }

    /**
     * Loads hotels codes and adds a behaviour (SheratonInfoLoader) that
     * is responsible for processing received codes.
     * 
	 * @see jade.core.behaviours.Behaviour#action()
	 */
	public void action() 
	{
        try
        {
            HotelDocument[] hotels = hiltonLoader.loadResources();
            String[] hotelsCodes = 
                hiltonLoader.extractHotelsCodes(hotels);
            
            ((WrapperAgent)myAgent).addBusinessSubBehaviour(
                    new HiltonInfoLoader(myAgent, hotelsCodes));
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
            ExceptionManager.publish(ex);
        }
	}
	
	public int onEnd()
	{
	    super.onEnd();
	    
		if (hiltonLoader.morePages2Load())
		{
			((WrapperAgent)myAgent).addBusinessSubBehaviour(this);
		}
		
		return 0;
	}
}
