package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.dto.HotelDocument;
import semfly.exceptions.WebSourceParseException;

/**
 * @author szymek
 *
 * This behaviour parses the DOM objects given with Hilton hotels info 
 * by using Jaxen and then creates an appropriate token to be send to 
 * the Coordinator (by using WrapperSender bahaviour).
 */
public class HiltonInfoProcessor extends ResourceProcessor
{

    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private HiltonInfoProcessorBL hiltonProcessor = null;
    
    /**
	 * Constructor.
	 * @param owner Agent - owner of this behaviour.
	 * @param hiltonDetails Web pages with Hilton hotels details.
	 */
	public HiltonInfoProcessor(Agent owner, HotelDocument[] hiltonDetails)
	{
		super(owner);
		
		hiltonProcessor = 
		    new HiltonInfoProcessorBL(owner, hiltonDetails);
	}
    
    /**
	 * Processes pages with hotels details. Extracts an importan info about
	 * hotels and creates Jena Model.
	 * 
	 * @see semfly.agents.behaviours.ResourceProcessor#processResource()
	 */
	protected void processResource() throws WebSourceParseException
	{
		model = hiltonProcessor.processResource();
	}

}
