package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.agents.WrapperAgent;
import semfly.dto.ResourceDocument;
import semfly.dto.WebPageDocument;
import semfly.exceptions.ExceptionManager;
import semfly.exceptions.WebSourceLoadException;
import semfly.exceptions.WebSourceParseException;
import semfly.dto.HotelLocation;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 * 
 * This class represents a Behaviour that is to load locations (their codes) 
 * of all Hilton Hotels.
 */
public class HiltonLocationsLoader extends ResourceLoader
{
    private HiltonLocationsLoaderBL hiltonLoader;
    
      public HiltonLocationsLoader(Agent agent)
      {
          super(agent);
          
          hiltonLoader = new HiltonLocationsLoaderBL(agent);
      }

      /** 
       * Loads Hilton Hotels locations and adds behaviour 
       * (HiltonHotelCodesLoader) responsible for loading hotels codes for
       * loaded locations.
       * 
       * @see semfly.agents.behaviours.ResourceLoader#loadResource()
       */
      protected ResourceDocument loadResource() throws WebSourceLoadException
      {
          WebPageDocument locations = hiltonLoader.loadLocations();
          
          try
          {
              HotelLocation[] locCodes = 
                  hiltonLoader.extractLocationCodes(locations.getWebDocument());
                    
              ((WrapperAgent)myAgent).addBusinessSubBehaviour(
  					new HiltonHotelCodesLoader(myAgent, 
  					        hiltonLoader.extractLocationCodes(
  					                locations.getWebDocument())));
  					                
          }
          catch (WebSourceParseException ex)
          {
              ExceptionManager.publish(ex);
          }
          
          return locations;
      }
}
