package semfly.agents.behaviours;

import java.util.Vector;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.lang.acl.ACLMessage;
import jade.proto.ContractNetInitiator;
import jade.content.ContentElement;
import jade.content.onto.basic.Action;
import semfly.agents.IndexingAgent;
import semfly.onto.jade.IndexToken;
import semfly.exceptions.ExceptionManager;
import semfly.onto.jade.SaveInDB;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for sending token request to the Coordinator.
 * After receiving a token, Indexing Agent save it into a RDF database.
 */
public class IndexingAgentRequestSender extends ContractNetInitiator
{
    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private IndexingAgentRequestSenderBL senderBL;
    
    public IndexingAgentRequestSender(Agent agent, ACLMessage rq)
    {
        super(agent, rq);
        senderBL = new IndexingAgentRequestSenderBL();
    }

    public IndexingAgentRequestSender(Agent agent, ACLMessage rq,
            DataStore ds)
    {
        super(agent, rq, ds);
        senderBL = new IndexingAgentRequestSenderBL();
    }
    
    /*
	protected void handlePropose(ACLMessage propose, Vector v) 
	{
		
	}

	protected void handleRefuse(ACLMessage refuse) 
	{

	}
	
	protected void handleFailure(ACLMessage failure) 
	{
		if (failure.getSender().equals(myAgent.getAMS())) 
		{
			// FAILURE notification from the JADE runtime: the receiver
			// does not exist
		    //((WrapperAgent)myAgent).removeBusinessSubBehaviour(this);
			System.out.println("Responder does not exist");
		}
		else 
		{
			System.out.println("Agent "+failure.getSender().getName()+" failed");
			//((WrapperAgent)myAgent).removeBusinessSubBehaviour(this);
			//((WrapperAgent)myAgent).addBusinessSubBehaviour(
				//	new DataTokenSender(myAgent, cfpMessage));
		}
	}
	*/
	
	/**
	 * Handles all responses. Overriden method.
	 */
	protected void handleAllResponses(Vector responses, Vector acceptances) 
	{
		evaluateProposals(responses, acceptances);					
	}
	
	/**
	 * Evaluates received proposals. 
	 * The best proposer is the one with the biggest number of tokens in its TPQ. 
	 *
	 * @param responses Parameter from the handleAllResponses method
	 * @param acceptances Parameter from the handleAllResponses method
	 * @return "The best" proposer message.
	 */
	private ACLMessage evaluateProposals(Vector responses, Vector acceptances)
	{
	    if (acceptances.size() == 0) 
	    {
			((IndexingAgent)myAgent).addRequestSenderBehaviour();
	    }
	       
		return senderBL.evaluateProposals(responses, acceptances);
	}

	/**
	 * In this INFORM message handler, a token (IndexToken) is extracted
	 * from the message and it's saved in DB.
	 */
    protected void handleInform(ACLMessage inform) 
	{
        IndexToken token = null;
		try
		{
			ContentElement ce = 
			    myAgent.getContentManager().extractContent(inform);
			
			SaveInDB saveAction = (SaveInDB)((Action)ce).getAction();
			token = saveAction.getIndexToken();
			senderBL.saveTokenInDB(token);
			
			System.out.println("Indexing Agent:  " + 
			        myAgent.getName() + " successfully saved a token");
		}
		catch (Exception ex)
		{
		    ex.printStackTrace();
		    ExceptionManager.publish(IndexingAgent.ServiceType, ex, token);
		}
	
		((IndexingAgent)myAgent).addRequestSenderBehaviour();
	}
}
