package semfly.agents.behaviours;

import jade.core.Agent;
import org.w3c.dom.Document;

import semfly.dto.HotelLocation;
import semfly.exceptions.ExceptionManager;
import semfly.agents.WrapperAgent;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for loading Marriot Hotels Codes.
 */
public class MarriottHotelCodesLoader extends ResourceLoader
{
    private MarriottHotelCodesLoaderBL marriottLoader;
    
    public MarriottHotelCodesLoader(Agent agent, HotelLocation[] hotelsLocations)
    {
        super(agent);

        marriottLoader = new MarriottHotelCodesLoaderBL(agent, hotelsLocations);
    }

    /**
     * Loads hotels codes and adds a behaviour (MarriottInfoLoader) that
     * is responsible for processing received codes.
     * 
	 * @see jade.core.behaviours.Behaviour#action()
	 */
	public void action() 
	{
        try
        {
            Document[] hotels = marriottLoader.loadResources();
            String[] hotelsCodes = marriottLoader.extractHotelsCodes(hotels);
            
            ((WrapperAgent)myAgent).addBusinessSubBehaviour(
                    new MarriottInfoLoader(myAgent, hotelsCodes));
        }
        catch (Exception ex)
        {
            ExceptionManager.publish(ex);
        }
	}
	
	public int onEnd()
	{
		if (marriottLoader.morePages2Load())
		{
			((WrapperAgent)myAgent).addBusinessSubBehaviour(this);
		}
		
		return 0;
	}
}
