package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.agents.WrapperAgent;
import semfly.dto.HotelDocument;
import semfly.exceptions.ExceptionManager;
import semfly.exceptions.WebSourceLoadException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible loading info about Marriott hotels for the hotels
 * codes given from www.marriott.com web site.
 */
public class MarriottInfoLoader extends ResourceLoader
{
    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private MarriottInfoLoaderBL marriottLoader = null;
	
	/**
	 * Constructor. Sets hotels codes for which all necessary details should 
	 * be loaded (hotelsCodes param) and currend code index on zero.
	 * @param owner Agent - owner of this behaviour.
	 * @param hotelsCodes Marriott hotels codes for which all necessary 
	 * details should be loaded.
	 */
	public MarriottInfoLoader(Agent owner, String[] hotelsCodes)
	{
	    super(owner);
	    
	    marriottLoader = new MarriottInfoLoaderBL(owner, hotelsCodes);
	}
	
	/** 
	 * Main mehtod of any Behaviour class.
	 * Starts loading info about hotels and adds beahviour 
	 * (MarriottInfoProcessor) responsible for processing loaded data.
	 * 
	 * @see jade.core.behaviours.Behaviour#action()
	 */
	public void action() 
	{
		try
		{
			HotelDocument[] hotelsDetails = marriottLoader.loadResources();
			((WrapperAgent)myAgent).addBusinessSubBehaviour(
					new MarriottInfoProcessor(myAgent, hotelsDetails));
		}
		catch (WebSourceLoadException ex)
		{
			ExceptionManager.publish(ex);
		}
	}
	
	/**
	 * If not all details are loaded (for all the given codes) 
	 * a new MarriottInfoLoader behaviour is added and the next details 
	 * are going to be loaded.
	 */
	public int onEnd()
	{
	    super.onEnd();
		if (marriottLoader.morePages2Load())
		{
			((WrapperAgent)myAgent).addBusinessSubBehaviour(this);
		}
		
		return 0;
	}
}
