package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.dto.HotelDocument;
import semfly.exceptions.WebSourceParseException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This behaviour parses the DOM objects given with Marriott hotels info 
 * by using Jaxen and then creates an appropriate token to be send to 
 * the Coordinator (by using WrapperSender bahaviour).
 */
public class MarriottInfoProcessor extends ResourceProcessor
{
    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private MarriottInfoProcessorBL marriottProcessor = null;
    
    /**
	 * Constructor.
	 * @param owner Agent - owner of this behaviour.
	 * @param marriottDetails Web pages with Marriott hotels details.
	 */
	public MarriottInfoProcessor(Agent owner, HotelDocument[] marriottDetails)
	{
		super(owner);
		
		marriottProcessor = 
		    new MarriottInfoProcessorBL(owner, marriottDetails);
	}
    
    /**
	 * Processes pages with hotels details. Extracts an importan info about
	 * hotels and creates Jena Model.
	 * 
	 * @see semfly.agents.behaviours.ResourceProcessor#processResource()
	 */
	protected void processResource() throws WebSourceParseException 
	{
		model = marriottProcessor.processResource();
	}
}
