package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.agents.WrapperAgent;
import semfly.dto.ResourceDocument;
import semfly.dto.WebPageDocument;
import semfly.exceptions.ExceptionManager;
import semfly.exceptions.WebSourceLoadException;
import semfly.exceptions.WebSourceParseException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class represents a Behaviour that is to load locations (their codes) 
 * of all Marriot Hotels. 
 * Starting page is: "http://marriott.com/search/hotelDirectory.mi?
 * country=PL&bc=&hotelDirectory=true";
 */
public class MarriottLocationsLoader extends ResourceLoader
{
    private MarriottLocationsLoaderBL marriottLoader;
  
    public MarriottLocationsLoader(Agent agent)
    {
        super(agent);
        
        marriottLoader = new MarriottLocationsLoaderBL(agent);
    }

    /** 
     * Loads Marriott Hotels locations and adds behaviour 
     * (MarriottHotelCodesLoader) responsible for loading hotels codes for
     * loaded locations.
     * 
     * @see semfly.agents.behaviours.ResourceLoader#loadResource()
     */
    protected ResourceDocument loadResource() throws WebSourceLoadException
    {
        WebPageDocument locations = marriottLoader.loadLocations();
        
        try
        {
            ((WrapperAgent)myAgent).addBusinessSubBehaviour(
					new MarriottHotelCodesLoader(myAgent, 
					        marriottLoader.extractLocationCodes(
					                locations.getWebDocument())));
        }
        catch (WebSourceParseException ex)
        {
            ExceptionManager.publish(ex);
        }
        
        return locations;
    }
}
