package semfly.agents.behaviours;

import jade.core.Agent;
import jade.core.behaviours.OneShotBehaviour;
import semfly.agents.WrapperAgent;
import semfly.dto.ResourceDocument;
import semfly.exceptions.ExceptionManager;
import semfly.exceptions.WebSourceLoadException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This abstract class is a base for all classes that are responsible for
 * loading resources. Owner of this behaviour must be a Wrapper Agent.
 */
public abstract class ResourceLoader extends OneShotBehaviour 
{
	protected ResourceLoader() 
	{	
	}
	
	public ResourceLoader(Agent a) 
	{
		super(a);
		
		assert a instanceof WrapperAgent;
	}
	
	/** 
	 * Main method of all Behaviour classes.
	 * Calls <code>loadResource()</code> method to start loading resource.
	 * 
	 * @see jade.core.behaviours.Behaviour#action()
	 */
	public void action() 
	{
		try
		{
			loadResource();
		}
		catch (Exception ex)
		{
			ExceptionManager.publish(WrapperAgent.ServiceType, 
			        "Loading resource failed", ex);
		}
	}
	
	public int onEnd()
	{
		return 0;
	}
	
	/**
	 * Should be overriden. This method is to load resorce,
	 * but now it returns null. 
	 */
	protected ResourceDocument loadResource() throws WebSourceLoadException
	{
	    return null;
	}
}
