package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.dto.SheratonHotelCode;
import semfly.dto.WebPageDocument;
import semfly.agents.WrapperAgent;
import semfly.dto.HotelLocation;
import semfly.exceptions.ExceptionManager;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for loading Sheraton Hotels Codes.
 */
public class SheratonHotelCodesLoader extends ResourceLoader
{
    private SheratonHotelCodesLoaderBL sheratonLoader;
    
    public SheratonHotelCodesLoader(Agent agent, HotelLocation[] hotelsLocations)
    {
        super(agent);
        
        sheratonLoader = new SheratonHotelCodesLoaderBL(agent, hotelsLocations);
    }

    /**
     * Loads hotels codes and adds a behaviour (SheratonInfoLoader) that
     * is responsible for processing received codes.
     * 
	 * @see jade.core.behaviours.Behaviour#action()
	 */
	public void action() 
	{
        try
        {
            WebPageDocument[] hotels = sheratonLoader.loadResources();
            SheratonHotelCode[] hotelsCodes = 
                sheratonLoader.extractHotelsCodes(hotels);
            
            ((WrapperAgent)myAgent).addBusinessSubBehaviour(
                    new SheratonInfoLoader(myAgent, hotelsCodes));
        }
        catch (Exception ex)
        {
            ExceptionManager.publish(ex);
        }
	}
	
	public int onEnd()
	{
	    super.onEnd();
	    
		if (sheratonLoader.morePages2Load())
		{
			((WrapperAgent)myAgent).addBusinessSubBehaviour(this);
		}
		
		return 0;
	}
}
