package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.dto.HotelDocument;
import semfly.agents.WrapperAgent;
import semfly.dto.SheratonHotelCode;
import semfly.exceptions.ExceptionManager;
import semfly.exceptions.WebSourceLoadException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for loading info about Sheraton hotels for the hotels
 * codes given from www.sheraton.com web site.
 */
public class SheratonInfoLoader extends ResourceLoader
{
    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private SheratonInfoLoaderBL sheratonLoader = null;
	
	/**
	 * Constructor. Sets hotels codes for which all necessary details should 
	 * be loaded (hotelsCodes param) and currend code index on zero.
	 * @param owner Agent - owner of this behaviour.
	 * @param hotelsCodes Sheraton hotels codes for which all necessary 
	 * details should be loaded.
	 */
	public SheratonInfoLoader(Agent owner, SheratonHotelCode[] hotelsCodes)
	{
	    super(owner);
	    
	    sheratonLoader = new SheratonInfoLoaderBL(owner, hotelsCodes);
	}
	
	/** 
	 * Main mehtod of any Behaviour class.
	 * Starts loading info about hotels and adds beahviour 
	 * (SheratonInfoProcessor) responsible for processing loaded data.
	 * 
	 * @see jade.core.behaviours.Behaviour#action()
	 */
	public void action() 
	{
		try
		{
		    HotelDocument[] hotelsDetails = sheratonLoader.loadResources();
		
		    ((WrapperAgent)myAgent).addBusinessSubBehaviour(
					new SheratonInfoProcessor(myAgent, hotelsDetails));
		}
		catch (WebSourceLoadException ex)
		{
			ExceptionManager.publish(ex);
		}
	}
	
	/**
	 * If not all details are loaded (for all the given codes) 
	 * a new SheratonInfoLoader behaviour is added and the next details 
	 * are going to be loaded.
	 */
	public int onEnd()
	{
	    super.onEnd();
	    
		if (sheratonLoader.morePages2Load())
		{
			((WrapperAgent)myAgent).addBusinessSubBehaviour(this);
		}
		
		return 0;
	}
}
