package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.dto.HotelDocument;
import semfly.exceptions.WebSourceParseException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This behaviour parses the DOM objects given with Sheraton hotels info 
 * by using Jaxen and then creates an appropriate token to be send to 
 * the Coordinator (by using WrapperSender bahaviour).
 */
public class SheratonInfoProcessor extends ResourceProcessor
{
    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private SheratonInfoProcessorBL sheratonProcessor = null;
    
    /**
	 * Constructor.
	 * @param owner Agent - owner of this behaviour.
	 * @param sheratonDetails Web pages with Sheraton hotels details.
	 */
	public SheratonInfoProcessor(Agent owner, HotelDocument[] sheratonDetails)
	{
		super(owner);
		
		sheratonProcessor = 
		    new SheratonInfoProcessorBL(owner, sheratonDetails);
	}
    
    /**
	 * Processes pages with hotels details. Extracts an importan info about
	 * hotels and creates Jena Model.
	 * 
	 * @see semfly.agents.behaviours.ResourceProcessor#processResource()
	 */
	protected void processResource() throws WebSourceParseException
	{
		model = sheratonProcessor.processResource();
	}

}
