package semfly.agents.behaviours;

import jade.core.Agent;
import semfly.agents.WrapperAgent;
import semfly.dto.ResourceDocument;
import semfly.dto.WebPageDocument;
import semfly.exceptions.ExceptionManager;
import semfly.exceptions.WebSourceLoadException;
import semfly.exceptions.WebSourceParseException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class represents a Behaviour that is to load locations (their codes) 
 * of all Sheraton Hotels. 
 * Starting page is: "http://www.starwoodhotels.com/sheraton/index.html";
 */
public class SheratonLocationsLoader extends ResourceLoader
{
    private SheratonLocationsLoaderBL sheratonLoader;
    
      public SheratonLocationsLoader(Agent agent)
      {
          super(agent);
          
          sheratonLoader = new SheratonLocationsLoaderBL(agent);
      }

      /** 
       * Loads Sheraton Hotels locations and adds behaviour 
       * (SheratonHotelCodesLoader) responsible for loading hotels codes for
       * loaded locations.
       * 
       * @see semfly.agents.behaviours.ResourceLoader#loadResource()
       */
      protected ResourceDocument loadResource() throws WebSourceLoadException
      {
          WebPageDocument locations = 
              (WebPageDocument)sheratonLoader.loadLocations();
          
          try
          {
              ((WrapperAgent)myAgent).addBusinessSubBehaviour(
  					new SheratonHotelCodesLoader(myAgent, 
  					      sheratonLoader.extractLocationCodes(
  					              locations.getWebDocument())));
          }
          catch (WebSourceParseException ex)
          {
              ExceptionManager.publish(ex);
          }
          
          return locations;
      }
}
