package semfly.agents.behaviours;

import java.util.Vector;
import semfly.agents.WrapperAgent;
import semfly.log.LogWriter;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.lang.acl.ACLMessage;
import jade.proto.ContractNetInitiator;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for sending an IndexToken to the Coordinator.
 * Owner of this class must be a Wrapper Agent.
 */
public class WrapperSender extends ContractNetInitiator
{
    /**
     * Message to send (passed in constructor).
     */
    private ACLMessage cfpMessage;
    
    /**
     * This class is responsible for "business logic" within this behaviour.
     */
    private WrapperSenderBL senderBL;
	
	public WrapperSender(Agent agent, ACLMessage msg)
	{
		super(agent, msg);
		
		assert myAgent instanceof WrapperAgent;
		
		cfpMessage = msg;
		senderBL = new WrapperSenderBL();
	}
	
	public WrapperSender(Agent agent, ACLMessage msg, DataStore ds)
	{
		super(agent, msg, ds);
		
		assert myAgent instanceof WrapperAgent;
		
		cfpMessage = msg;
		senderBL = new WrapperSenderBL();
	}
	
	/*
	protected void handlePropose(ACLMessage propose, Vector v) 
	{
		
	}

	protected void handleRefuse(ACLMessage refuse) 
	{

	}
	*/
	
	/**
	 * Handles failure message.
	 * This method is called when:
	 * 1. The receiver doesn't exist THEN saves info about it with the whole
	 * 		ACL message (cfpMessage to system log)
	 * 2. Coordinator failed saving a token in its TPQ THEN adds this behaviour 
	 * 		to the owner's bahaviour (in other words: retry to send the message). 
	 */
	protected void handleFailure(ACLMessage failure) 
	{
		if (failure.getSender().equals(myAgent.getAMS())) 
		{
			//FAILURE notification from the JADE runtime: the receiver
			//does not exist
			LogWriter.writeWarn2Log(WrapperAgent.ServiceType, 
			        "Responder does not exist", cfpMessage);
		}
		else 
		{
			((WrapperAgent)myAgent).addBusinessSubBehaviour(
					new WrapperSender(myAgent, cfpMessage));
		}
	}
	
	/**
	 * Handles all responses. Overriden method.
	 */
	protected void handleAllResponses(Vector responses, Vector acceptances) 
	{
		senderBL.evaluateProposals(responses, acceptances);					
	}
	
	protected void handleInform(ACLMessage inform) 
	{
		System.out.println("Coordinator Agent:  " + 
		        inform.getSender().getName() + " successfully received a token");
	}
}
