package semfly.coordination;

import semfly.agents.AgentInfo;
import semfly.agents.WrapperAgentInfo;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.Iterator;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.util.List;
import org.jaxen.dom.DOMXPath;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * @author Szymek
 *
 * This class is responsible for reading Wrapper Agents' schedules from a file.
 * Not Done Yet!!!
 */
public class ScheduleReader
{
    private String configFilePath = "etc/semfly.config";
    
	/**
	 * 
	 */
	public ScheduleReader()
	{
	}

	public AgentInfo[] readIndexingAgents() throws Exception
	{
	    int quantity = -1;
	    String className = null;
	    
	    Document configDoc = formDocument(configFilePath);
	   
	    DOMXPath xpath = new DOMXPath("//indexingAgents[1]/quantity[1]/text()");
		Node node = (Node)xpath.selectSingleNode(configDoc);
		quantity = Integer.parseInt(node.getNodeValue());
		
		xpath = new DOMXPath("//indexingAgents[1]/className[1]/text()");
		node = (Node)xpath.selectSingleNode(configDoc);
		className = node.getNodeValue();
		
		AgentInfo[] agents = new AgentInfo[quantity];
	    
		for (int i = 0; i < agents.length; i++)
		    agents[i] = new AgentInfo("IndexingAgent_" + (i + 1), 
		            				className, null);
		
		return agents;
	}
	
	public WrapperAgentInfo[] readWrapperAgents(String fileName) throws Exception
	{
	    WrapperAgentInfo[] agentsSchedule;
	    
	    Document configDoc = formDocument(configFilePath);
		  
	    DOMXPath xpath = new DOMXPath("//wrapperAgents[1]/wrapperAgent");
	    List nodes = xpath.selectNodes(configDoc);
	    Iterator nodesIter = nodes.iterator();
	    Node node, tmpNode;
	    int i = 0;
	    agentsSchedule = new WrapperAgentInfo[nodes.size()];
	    String name, className, tmp;
	    long freqOfVisits;
		while (nodesIter.hasNext())
		{
		    
		    node = (Node)nodesIter.next();
		    name = node.getAttributes().getNamedItem("name").getNodeValue();
		    
		    xpath = new DOMXPath("className[1]");
		    tmpNode = (Node)xpath.selectSingleNode(node);
		    className = tmpNode.getFirstChild().getNodeValue();
		    
		    xpath = new DOMXPath("freqOfVisits[1]");
		    tmpNode = (Node)xpath.selectSingleNode(node);
		    tmp = tmpNode.getFirstChild().getNodeValue();
		    freqOfVisits = Long.parseLong(tmp);
		    
		    agentsSchedule[i++] = new WrapperAgentInfo(name, className, 
		            					null, freqOfVisits);
		}
		
		return agentsSchedule;
	}
	
	public WrapperAgentInfo[][] readWrappersScheduleSorted() throws Exception
	{
		WrapperAgentInfo[] agentsInfo = readWrapperAgents(null);
		return sortWrappersBySchedule(agentsInfo);
	}
	
	public WrapperAgentInfo[][] sortWrappersBySchedule(
	        WrapperAgentInfo[] agentsInfo)
	{
	    if (agentsInfo == null)
	        throw new IllegalArgumentException("Array with wrapper agents info" +
	                " can't be null!");
	    
	    if (agentsInfo.length == 0) return new WrapperAgentInfo[][]{};
	    Arrays.sort(agentsInfo);
		
		WrapperAgentInfo currentAgent = agentsInfo[0];
		ArrayList equalSchedule = new ArrayList(), 
			sortedSchedule = new ArrayList();
		
		equalSchedule.add(currentAgent);
		for (int i = 1; i < agentsInfo.length; i++)
		{
			if (agentsInfo[i].compareTo(currentAgent) == 0)
			{
				equalSchedule.add(agentsInfo[i]);
			}
			else
			{
				sortedSchedule.add(equalSchedule.toArray(
						new WrapperAgentInfo[equalSchedule.size()]));
				
				currentAgent = agentsInfo[i]; 
				equalSchedule = new ArrayList();
				equalSchedule.add(currentAgent);
			}
			
		}
		sortedSchedule.add(equalSchedule.toArray(
				new WrapperAgentInfo[equalSchedule.size()]));
		
		return (WrapperAgentInfo[][])sortedSchedule.toArray(
				new WrapperAgentInfo[sortedSchedule.size()][]);
	}
	
    private Document formDocument(String fileName) throws Exception
    {
	    DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
	    DocumentBuilder builder = factory.newDocumentBuilder();
	    Document document = builder.parse(fileName);
	    
	    return document;
    }
}
