package semfly.exceptions;

import org.apache.log4j.Logger;


/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 * 
 * This class is responsible for managing exceptions.
 */
public class ExceptionManager
{
	private ExceptionManager()
	{
	}
	
	/**
	 * Publishes the exception given by writing it to the system log (file)
	 * under root category.
	 * 
	 * @param ex Exception to publish.
	 */
	public static void publish(Exception ex)
	{
		if (ex == null) throw new 
			IllegalArgumentException("Exception to publish can't be null");
		
		System.out.println("Error occured - please check CCS log for more info.");
		try
	    {
		    Logger logger = Logger.getRootLogger();
		    logger.error(ex.toString() + "\nSTACK TRACE: " + getStackTrace(ex));
	    }
	    catch (Exception e){}
	}
	
	/**
	 * Publishes the message (msg) given by writing it to CCS log (file) 
	 * under the category given.
	 */
	public static void publish(String category, String msg)
	{
	    if (category == null) 
	        throw new IllegalArgumentException("Category can't be null");
	    if (msg == null) throw new 
			IllegalArgumentException("Message to publish can't be null");
	    
	    System.out.println("Error occured - please check CCS log for more info.");
	    try
	    {
		    Logger logger = Logger.getLogger(category);
		    logger.error(msg);
	    }
	    catch (Exception e){}
	}
	
	/**
	 * Publishes the exception (ex) given including information from 
	 * the object (obj) given by writing it to log (file) under the category
	 * given.
	 */
	public static void publish(String category, Exception ex, Object obj)
	{
	    if (category == null) 
	        throw new IllegalArgumentException("Category can't be null");
	    if (ex == null) throw new 
			IllegalArgumentException("Exception to publish can't be null");
	    if (obj == null) throw new 
			IllegalArgumentException("Object to publish can't be null");
	    
	    ExceptionManager.publish(category, ex + "\nEXTRA OBJECT: " + obj);
	}
	
	/**
	 * Publishes the exception (ex) given with the message given
	 * by writing it to CCS log (file) under the category given.
	 */
	public static void publish(String category, String msg, Exception ex)
	{
	    if (category == null) 
	        throw new IllegalArgumentException("Category can't be null");
	    if (msg == null) throw new 
			IllegalArgumentException("Message to publish can't be null");
	    if (ex == null) throw new 
			IllegalArgumentException("Exception to publish can't be null");
	    
	    ExceptionManager.publish(category, msg + "\nEXCEPTION: " + ex);
	 }
	
	/**
	 * Returns stack trace of the exception given.
	 */
	private static String getStackTrace(Exception ex)
	{
	    if (ex == null) throw new 
			IllegalArgumentException("Exception to publish can't be null");
	    
	    StackTraceElement[] stackTrace = ex.getStackTrace();
	    
	    StringBuffer strStackTrace = new StringBuffer();
	    for (int i = 0; i < stackTrace.length; i++)
	    {
	        strStackTrace.append(stackTrace[i].toString());
	        strStackTrace.append("\n");
	    }
	    
	    return strStackTrace.toString();
	}
}
