package semfly.exceptions;

import jade.core.AID;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * Wrapper Exception - an type of exception that can be thrown by a wrapper agent
 */
public class WrapperException extends AgentException
{
    String webSource;
    
    /**
     * @param agent
     */
    public WrapperException(AID agent, String webSourceAddr)
    {
        super(agent);
        setWebSource(webSourceAddr);
    }

    /**
     * @param agent
     * @param message
     */
    public WrapperException(AID agent, String webSourceAddr, String message)
    {
        super(agent, message);
        setWebSource(webSourceAddr);
    }

    /**
     * @param agent
     * @param message
     * @param innerEx
     */
    public WrapperException(AID agent, String message, Throwable innerEx,
            	String webSourceAddr)
    {
        super(agent, message, innerEx);
        setWebSource(webSourceAddr);
    }
    
    /**
     * @param agent
     * @param message
     * @param innerEx
     */
    public WrapperException(AID agent, String message, Throwable innerEx)
    {
        super(agent, message, innerEx);
    }
    
    /**
     * @return Returns the webSource.
     */
    public String getWebSource()
    {
        return webSource;
    }
    
    /**
     * @param webSource The webSource to set.
     */
    protected void setWebSource(String webSource)
    {
        assert webSource != null;
        
        this.webSource = webSource;
    }
    
    public String toString()
    {
        String errorMsg = this.getClass().toString(); 
        
        errorMsg += "  \n" + getStackTraceString();
        errorMsg += "WEB SOURCE: " + webSource;
        
        return errorMsg;
    }
}
