package semfly.globals;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import semfly.agents.SystemGUIAgent;
import jade.gui.GuiEvent;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class represents GUI to the Content Collection Subsystem.
 */
public class SystemGUI extends JFrame implements GUIVocabulary
{
    /**
     * GUI agent for the Content Collection Subsystem.
     */
    private SystemGUIAgent guiAgent;
    
    public SystemGUI(SystemGUIAgent agent)
    {
        assert agent != null;
        
        guiAgent = agent;
        
        setTitle("Content Collection Subsystem");
        setPreferredSize(new Dimension(375, 100));
        createStartShutdownPanel();
    }
    
    private void createStartShutdownPanel()
    {
        JPanel panel = new JPanel();
		panel.setLayout(new GridLayout(1, 2));
		
		panel.add(createStartButton());
		panel.add(createShutdownButton());
		getContentPane().add(panel, BorderLayout.CENTER);
    }
    
    private JButton createStartButton()
    {
        JButton btnStart = new JButton("Gather information");
        btnStart.addActionListener( new ActionListener() {
			public void actionPerformed(ActionEvent ev) 
			{
				GuiEvent ge = new GuiEvent(this, START_CCS);
				guiAgent.postGuiEvent(ge);
				System.out.println("start gui");
			}
		} );
		
		return btnStart;
    }
    
    private JButton createShutdownButton()
    {
        JButton btnShutdown = new JButton("Shutdown");
        btnShutdown.addActionListener( new ActionListener() {
			public void actionPerformed(ActionEvent ev) {
			    GuiEvent ge = new GuiEvent(this, SHUTDOWN_CCS);
				guiAgent.postGuiEvent(ge);
			}
		} );
		
		return btnShutdown;
    }
    
    /**
     * Creates and shows the system GUI.
     */
    public void createAndShowGUI() 
    {
		pack();
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		int centerX = (int)screenSize.getWidth() / 2;
		int centerY = (int)screenSize.getHeight() / 2;
		setLocation(centerX - getWidth() / 2, centerY - getHeight() / 2);
		super.setVisible(true);
	}
    
    /**
     * Main method.
     * @param args
     */
    public static void main(String[] args) 
    {
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            public void run() 
            {
                SystemGUI systemGUI = new SystemGUI(new SystemGUIAgent());
                systemGUI.createAndShowGUI();
            }
        });
    }
}
