package semfly.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import semfly.agents.SystemGUIAgent;
import jade.gui.GuiEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JOptionPane;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class represents GUI to the Content Collection Subsystem.
 */
public class SystemGUI extends JFrame implements GUIVocabulary
{
    /**
     * GUI agent for the Content Collection Subsystem.
     */
    private SystemGUIAgent guiAgent;
    
    private boolean systemStarted = false;
    private boolean systemShoutedDown = false;
    
    public SystemGUI(SystemGUIAgent agent)
    {
        assert agent != null;
        
        guiAgent = agent;
        
        setTitle("Content Collection Subsystem");
        setPreferredSize(new Dimension(375, 100));
        createStartShutdownPanel();
   
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) 
            {
               shutdown();
            }
         });
    }
    
    private void createStartShutdownPanel()
    {
        JPanel panel = new JPanel();
		panel.setLayout(new GridLayout(1, 2));
		
		panel.add(createStartButton());
		panel.add(createShutdownButton());
		getContentPane().add(panel, BorderLayout.CENTER);
    }
    
    private JButton createStartButton()
    {
        JButton btnStart = new JButton("Gather information");
        btnStart.addActionListener( new ActionListener() {
			public void actionPerformed(ActionEvent ev) 
			{
			    if (!systemStarted)
			    {
					GuiEvent ge = new GuiEvent(this, START_CCS);
					guiAgent.postGuiEvent(ge);
					systemStarted = true;
				}
			}
		} );
		
		return btnStart;
    }
    
    private JButton createShutdownButton()
    {
        JButton btnShutdown = new JButton("Shutdown");
        btnShutdown.addActionListener( new ActionListener() {
			public void actionPerformed(ActionEvent ev) {
			    if (!systemShoutedDown)
			    {
				    GuiEvent ge = new GuiEvent(this, SHUTDOWN_CCS);
					guiAgent.postGuiEvent(ge);
					systemShoutedDown = true;
			    }
			}
		} );
		
		return btnShutdown;
    }
    
    /**
     * Creates and shows the system GUI.
     */
    public void showGUI() 
    {
		pack();
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		int centerX = (int)screenSize.getWidth() / 2;
		int centerY = (int)screenSize.getHeight() / 2;
		setLocation(centerX - getWidth() / 2, centerY - getHeight() / 2);
		super.setVisible(true);
	}
    
    /**
     * Shutdowns the Content Collection Subsystem.
     */
    private void shutdown()
    {
        int rep = JOptionPane.showConfirmDialog(this, 
                "Are you sure you want to exit?",
                guiAgent.getLocalName(),
                JOptionPane.YES_NO_CANCEL_OPTION);
        
		if (rep == JOptionPane.YES_OPTION) 
		{
		    GuiEvent ge = new GuiEvent(this, SHUTDOWN_CCS);
			guiAgent.postGuiEvent(ge);
		}
    }
}
