package semfly.net;

import java.io.IOException;

import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpException;
import org.apache.commons.httpclient.HttpMethod;
import org.cyberneko.html.parsers.DOMParser;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import javax.xml.parsers.DocumentBuilder; 
import javax.xml.parsers.DocumentBuilderFactory;  
import javax.xml.parsers.ParserConfigurationException;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 * 
 * This class is responsible for loading a web site.
 */
public class WebSiteLoader
{
    HttpClient client;
    
	/**
	 * 
	 */
	public WebSiteLoader()
	{
		client = new HttpClient();
	}
	
	/**
	 * Loads a web site that is written in HTML for the given address. 
	 * @param httpMethod Access method with url address and all requires parameters
	 * 			to a web site. 
	 * @return Loaded web site as a DOM Document.
	 */
	public Document loadWebSiteHTML(HttpMethod httpMethod) throws HttpException,
		SAXException, IOException
	{
		DOMParser parser = new DOMParser();
		parser.parse(loadWebSite(httpMethod));
		
		//httpMethod.recycle();
		return parser.getDocument();
	}
	
	/**
	 * Loads a web site that is written in XHTML for the given address. 
	 * @param httpMethod Access method with url address and all requires parameters
	 * 			to a web site. 
	 * @return Loaded web site as DOM Document.
	 */
	public Document loadWebSiteXHTML(HttpMethod httpMethod) throws HttpException,
		SAXException, IOException, ParserConfigurationException
	{
		 DocumentBuilderFactory factory =
	            DocumentBuilderFactory.newInstance();
		 
		 DocumentBuilder builder = factory.newDocumentBuilder();
         return builder.parse(loadWebSite(httpMethod));
	}
	
	/**
	 * Loads a web site by means of the HTTP method given.
	 */
	public InputSource loadWebSite(HttpMethod httpMethod) throws HttpException,
	        IOException
	{
		client.executeMethod(httpMethod);
		return new InputSource(httpMethod.getResponseBodyAsStream());
	}
}
