package semfly.textmining;

import java.util.ArrayList;
import java.util.Hashtable;
import semfly.onto.jena.Hotel;

import com.hp.hpl.jena.rdf.model.Resource;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * Fake text miner. 
 */
public class HiltonTextMiner
{
    private static HiltonTextMiner instance;
    private static Hashtable roomAmenities;
    private static Hashtable guestRoomInfo; 
    private static Hashtable recreationInfo;
    private static Hashtable petPolicyInfo;
    private static Hashtable siteAmenities;
    private static Hashtable businessServices;
    
    private static ArrayList notImportantProperties;
    
    static
    {
        notImportantProperties = new ArrayList();
    }
    
    private HiltonTextMiner()
    {}
    
    public static HiltonTextMiner getInstance()
    {
        if (instance == null) 
        {
            instance = new HiltonTextMiner();
            createGuestRoomDescription();
            createRoomAmenitiesDescription();
            createRecreationDescription();
            createPetPolicyDescription();
            createSiteAmenitiesDescription();
            createBusinessServicesDescription();
        }
        
        return instance;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getAmenityDescription(String text)
    {
        TextDescription desc = (TextDescription)roomAmenities.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getGuestRoomDescription(String text)
    {
        TextDescription desc = (TextDescription)guestRoomInfo.get(text);
       
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getGuestRoomInfo(String text)
    {
        TextDescription desc = (TextDescription)guestRoomInfo.get(text);
      
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getRecreationDescription(String text)
    {
        TextDescription desc = (TextDescription)recreationInfo.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getPetsPolicyDescription(String text)
    {
        TextDescription desc = (TextDescription)petPolicyInfo.get(text);
       
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getSiteAmenityDescription(String text)
    {
        TextDescription desc = (TextDescription)siteAmenities.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getBusinessServiceDescription(String text)
    {
        TextDescription desc = (TextDescription)businessServices.get(text);
        
        return desc;
    }
    
    private static void createRoomAmenitiesDescription()
    {
        roomAmenities = new Hashtable();
        
        roomAmenities.put("AirConditioning", 
                new TextDescription(Hotel.roomAmenity, Hotel.AirConditioning));
        roomAmenities.put("AlarmClock", 
                new TextDescription(Hotel.roomAmenity, Hotel.AlarmClock));
        roomAmenities.put("Bottledwater,forafee", 
                new TextDescription(Hotel.roomAmenity, Hotel.BottledWater));
        roomAmenities.put("Accessible", 
                new TextDescription(Hotel.roomAmenity, Hotel.AccessibleRoom));
        roomAmenities.put("CoffeeandTeaMaker", 
                new TextDescription(Hotel.roomAmenity, Hotel.Coffee_TeaMaker));
        roomAmenities.put("Cribs", 
                new TextDescription(Hotel.roomAmenity, Hotel.Cribs));
        roomAmenities.put("Electricaladapters", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.ElectricalAdaptorsAvailable));
        roomAmenities.put("IndividualClimateControl", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.AirConditioningIndividuallyControlledInRoom));
        roomAmenities.put("Ironandironingboard", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.Iron, Hotel.IroningBoard}));
        roomAmenities.put("Safe", 
                new TextDescription(Hotel.roomAmenity, Hotel.Safe));
        roomAmenities.put("Bathrobes", 
                new TextDescription(Hotel.roomAmenity, Hotel.Bathrobe));
        roomAmenities.put("Bathroomamenities", 
                new TextDescription(Hotel.roomAmenity, Hotel.BathroomAmenities));
        roomAmenities.put("Bathtubwithsprayjets", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.BathTubWithSprayJets));
        roomAmenities.put("Hairdryer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Hairdryer));
        roomAmenities.put("TV-Cable", 
                new TextDescription(Hotel.roomAmenity, Hotel.CableTelevision));
        roomAmenities.put("ColorTV", 
                new TextDescription(Hotel.roomAmenity, Hotel.ColorTelevision));
        roomAmenities.put("MiniBar", 
                new TextDescription(Hotel.roomAmenity, Hotel.Minibar));
        roomAmenities.put("VCRplayer", 
                new TextDescription(Hotel.roomAmenity, Hotel.VCRPlayer));
        roomAmenities.put("Electricaloutlet:desklevel", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.DeskWithElectricalOutlet));
        roomAmenities.put("TV-Payperview", 
                new TextDescription(Hotel.roomAmenity, Hotel.PayPerViewMoviesOnTV));
        roomAmenities.put("Refrigerator", 
                new TextDescription(Hotel.roomAmenity, Hotel.Refrigerator));
        roomAmenities.put("Washer/dryer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Washer_dryer));
        roomAmenities.put("Wetbar", 
                new TextDescription(Hotel.roomAmenity, Hotel.WetBar));
        roomAmenities.put("Toaster", 
                new TextDescription(Hotel.roomAmenity, Hotel.Toaster));
        roomAmenities.put("FaxMachine", 
                new TextDescription(Hotel.roomAmenity, Hotel.FaxMachine));
        roomAmenities.put("CDplayer", 
                new TextDescription(Hotel.roomAmenity, Hotel.CDplayer));
        roomAmenities.put("Dishwasher", 
                new TextDescription(Hotel.roomAmenity, Hotel.Dishwasher));
        roomAmenities.put("JacuzziinRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.Jacuzzi));
        roomAmenities.put("Printer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Printer));
        roomAmenities.put("Fireplace", 
                new TextDescription(Hotel.roomAmenity, Hotel.Fireplace));
        roomAmenities.put("VCRmoviesforrent", 
                new TextDescription(Hotel.roomAmenity, Hotel.VCRRental));
        roomAmenities.put("Phonefeature:cordless", 
                new TextDescription(Hotel.roomAmenity, Hotel.CordlessPhone));
        roomAmenities.put("Separatetubandshower", 
                new TextDescription(Hotel.roomAmenity, Hotel.SeparateTubAndShower));
        roomAmenities.put("Movies/videos,pay-per-view", 
                new TextDescription(Hotel.roomAmenity, Hotel.PayPerViewMoviesOnTV));
        roomAmenities.put("Tableandchairs", 
                new TextDescription(Hotel.roomAmenity, Hotel.TablesAndChairs));
        roomAmenities.put("Internetbrowser/WebTV", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.InteractiveWebTV}));
        roomAmenities.put("Phonefeature:speakerphone", 
                new TextDescription(Hotel.roomAmenity, Hotel.SpeakerPhone));
        roomAmenities.put("Telephone-TwoLine", 
                new TextDescription(Hotel.roomAmenity, Hotel.Two_linePhone));
        roomAmenities.put("MicrowaveOven", 
                new TextDescription(Hotel.roomAmenity, Hotel.Microwave));
        roomAmenities.put("Silverware", 
                new TextDescription(Hotel.roomAmenity, Hotel.Silverware_utensils));
        roomAmenities.put("Stove", 
                new TextDescription(Hotel.roomAmenity, Hotel.Stove));
        roomAmenities.put("Trouserpress", 
                new TextDescription(Hotel.roomAmenity, Hotel.Trouser_PantPress));
        roomAmenities.put("Bottledwater", 
                new TextDescription(Hotel.roomAmenity, Hotel.BottledWater));
        roomAmenities.put("Conventionaloven", 
                new TextDescription(Hotel.roomAmenity, Hotel.Oven));
        roomAmenities.put("Pots,pans,servingdishes", 
                new TextDescription(Hotel.roomAmenity, Hotel.PotsAndPans));
        roomAmenities.put("Waterpurificationsystem", 
                new TextDescription(Hotel.roomAmenity, Hotel.WaterPurificationSystem));
        roomAmenities.put("Refrigeratorwithicemaker", 
                new TextDescription(Hotel.roomAmenity, Hotel.RefrigeratorWithIceMaker));
        roomAmenities.put("Telephone-VoiceMail", 
                new TextDescription(Hotel.roomAmenity, Hotel.VoiceMail));
        roomAmenities.put("SofaBed", 
                new TextDescription(Hotel.roomAmenity, Hotel.SofaBed));
        roomAmenities.put("ElectronicSmokeDetector", 
                new TextDescription(Hotel.roomAmenity, Hotel.SmokeDetectors));
        roomAmenities.put("FreeDailyNewspaper", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("Non-Smoking", 
                new TextDescription(Hotel.roomAmenity, Hotel.nonsmokingRooms));
        roomAmenities.put("Wake-upServiceAvailable", 
                new TextDescription(Hotel.roomAmenity, Hotel.Wake_upCalls));
        roomAmenities.put("Telephone-withDataport", 
                new TextDescription(Hotel.roomAmenity, Hotel.DataPort));
        roomAmenities.put("Fax/Copier/Printer", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.FaxMachine, Hotel.Printer}));
        roomAmenities.put("Iron/IroningBoard", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.Iron, Hotel.IroningBoard}));
        roomAmenities.put("WorkDesk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("FreeHighSpeedInternetAccessinAllGuestRooms", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.HighSpeedInternetConnection}));
        roomAmenities.put("Kitchenette", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("Television", 
                new TextDescription(Hotel.roomAmenity, Hotel.ColorTelevision));
        roomAmenities.put("CordlessTelephone", 
                new TextDescription(Hotel.roomAmenity, Hotel.CordlessPhone));
        roomAmenities.put("HighSpeedInternetAccessbyRequest(Charge)", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.HighSpeedInternetConnection}));
        roomAmenities.put("Desk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("Telephone-inBath", 
                new TextDescription(Hotel.roomAmenity, Hotel.BathroomTelephone));
        roomAmenities.put("InternationalDirectDialing", 
                new TextDescription(Hotel.roomAmenity, Hotel.InternationalDirectDialing));
        roomAmenities.put("Telephone", 
                new TextDescription(Hotel.roomAmenity, Hotel.Telephone));
        roomAmenities.put("FreeNewspaperonWeekdays", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("Radio/AlarmClock", 
                new TextDescription(Hotel.roomAmenity, Hotel.AlarmClock));
        roomAmenities.put("ConnectingRooms", 
                new TextDescription(Hotel.roomAmenity, Hotel.ConnectingRooms));
        roomAmenities.put("CDPlayer/Radio/AlarmClock", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.CDplayer, Hotel.AlarmClock}));
        roomAmenities.put("Bathrobe", 
                new TextDescription(Hotel.roomAmenity, Hotel.Bathrobe));
        roomAmenities.put("BathroomAmenities", 
                new TextDescription(Hotel.roomAmenity, Hotel.BathroomAmenities));
        roomAmenities.put("RoomwithFireplace", 
                new TextDescription(Hotel.roomAmenity, Hotel.Fireplace));
        roomAmenities.put("OversizedDesk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("NewspaperDeliv'dM-F(Local)", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("NewspaperDeliv'dW/E(Local)", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("KnockLight(HearingImpaired)", 
                new TextDescription(Hotel.roomAmenity, Hotel.KnockLight));
        roomAmenities.put("Telephone-withSpeakerphone", 
                new TextDescription(Hotel.roomAmenity, Hotel.SpeakerPhone));
        roomAmenities.put("RoomwithSittingArea", 
                new TextDescription(Hotel.roomAmenity, Hotel.SittingArea));
        roomAmenities.put("TurndownService", 
                new TextDescription(Hotel.roomAmenity, Hotel.TurnDownService));
        roomAmenities.put("WetBar", 
                new TextDescription(Hotel.roomAmenity, Hotel.WetBar));
        roomAmenities.put("FreeLocalCalls", 
                new TextDescription(Hotel.roomAmenity, Hotel.FreeLocalCalls));
        roomAmenities.put("OversizedDesk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("HighSpeedInternetAccess", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.HighSpeedInternetConnection}));
        roomAmenities.put("Bidet", 
                new TextDescription(Hotel.roomAmenity, Hotel.Bidet));
        roomAmenities.put("Telephone-AutoWakeup", 
                new TextDescription(Hotel.hotelAmenity, Hotel.WakeupService));
        roomAmenities.put("TelevisionwithRemoteControl", 
                new TextDescription(Hotel.roomAmenity, Hotel.ColorTelevision));
        roomAmenities.put("TrouserPress", 
                new TextDescription(Hotel.roomAmenity, Hotel.Trouser_PantPress));
        roomAmenities.put("InternetServiceProvidedinAllGuestRooms(Charge)", 
                new TextDescription(Hotel.roomAmenity, Hotel.InternetAccess));
        roomAmenities.put("HandicapAccessibleRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.AccessibleRoom));
        roomAmenities.put("TelevisionwithInternetAccessandWirelessKeyboardinGuestRooms(Charge)", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.ColorTelevision}));
        roomAmenities.put("DirectDialing", 
                new TextDescription(Hotel.roomAmenity, Hotel.DirectDialPhoneNumber));
        roomAmenities.put("FullKitchen", 
                new TextDescription(Hotel.roomAmenity, Hotel.Kitchen));
        roomAmenities.put("Iron", 
                new TextDescription(Hotel.roomAmenity, Hotel.Iron));
        roomAmenities.put("IroningBoard", 
                new TextDescription(Hotel.roomAmenity, Hotel.IroningBoard));
        roomAmenities.put("TV-PremiumHBO,CNN,ESPN", 
                new TextDescription(Hotel.roomAmenity, Hotel.CNNavailaible));
        roomAmenities.put("Rollaways", 
                new TextDescription(Hotel.roomAmenity, Hotel.Roll_Aways));
        roomAmenities.put("MiniRefrigerator", 
                new TextDescription(Hotel.roomAmenity, Hotel.Mini_refrigerator));
        roomAmenities.put("Modem", 
                new TextDescription(Hotel.roomAmenity, Hotel.Modem));
        roomAmenities.put("CoffeeMaker", 
                new TextDescription(Hotel.roomAmenity, Hotel.Coffee_TeaMaker));
        roomAmenities.put("Internetaccessinguestroom", 
                new TextDescription(Hotel.roomAmenity, Hotel.InternetAccess));
        roomAmenities.put("Telephone-TwoPhones", 
                new TextDescription(Hotel.roomAmenity, Hotel.Telephone));
        roomAmenities.put("Telephone-TwoPhones", 
                new TextDescription(Hotel.roomAmenity, Hotel.Telephone));
        roomAmenities.put("NewspaperM-F(USAToday)", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("Telephone-TwoLines", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        //
        
        
        roomAmenities.put("OceanViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.OceanView));
        roomAmenities.put("CityViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.CityView));
        roomAmenities.put("MountainViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.MountainView));
        roomAmenities.put("PoolViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.PoolView));
        roomAmenities.put("BayViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.BayView));
        roomAmenities.put("RiverViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.RiverView));
        roomAmenities.put("SeaViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.WaterView));
        roomAmenities.put("LakeViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.LakeView));
        roomAmenities.put("LakeViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.WaterView));
        roomAmenities.put("River/CityViewRoom", 
                new TextDescription(Hotel.roomViewType, 
                        new Resource[]{Hotel.RiverView, Hotel.CityView}));
        roomAmenities.put("CourtyardViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.CourtyardView));
        
        
        //services
        roomAmenities.put("24HourHousekeeping", 
                new TextDescription(Hotel.hotelAmenity, Hotel.hour24RoomService));
    }
    
    private static void createGuestRoomDescription()
    {
        guestRoomInfo = new Hashtable();
        
        guestRoomInfo.put("Airconditioning", 
                new TextDescription(Hotel.roomInfo, 
                        Hotel.airConditionedGuestRooms));
        
        guestRoomInfo.put("floors", 
                new TextDescription(Hotel.roomInfo, Hotel.floors));
        guestRoomInfo.put("rooms", 
                new TextDescription(Hotel.roomInfo, Hotel.totalRooms));
        guestRoomInfo.put("suites", 
                new TextDescription(Hotel.roomInfo, Hotel.suites));
        guestRoomInfo.put("TheRoomThatWorksguestrooms", 
                			new TextDescription(Hotel.roomInfo, Hotel.roomsThatWork));
        guestRoomInfo.put("totalRoomsAndSuites", 
    			new TextDescription(Hotel.roomInfo, Hotel.totalRoomsAndSuites));
    }
    
    private static void createRecreationDescription()
    {
        recreationInfo = new Hashtable();
     
        recreationInfo.put("JoggingTrack", 
    			new TextDescription(Hotel.hotelAmenity, Hotel.JoggingTrack));
        recreationInfo.put("Pool", 
    			new TextDescription(Hotel.hotelAmenity, Hotel.Pool));
        recreationInfo.put("Beach", 
    			new TextDescription(Hotel.hotelAmenity, Hotel.Beach));
        recreationInfo.put("Golfcourse", 
    			new TextDescription(Hotel.hotelAmenity, Hotel.GolfLocationOnsite));
        recreationInfo.put("TennisCourt", 
    			new TextDescription(Hotel.hotelAmenity, Hotel.TennisCourt));
    }
    
    private static void createPetPolicyDescription()
    {
        petPolicyInfo = new Hashtable();
        petPolicyInfo.put("Allowed", 
                new TextDescription(Hotel.petsPolicy, Hotel.PetsAllowed));
        petPolicyInfo.put("No Pets Allowed", 
                new TextDescription(Hotel.petsPolicy, Hotel.PetsAllowed));
    }
    
    private static void createSiteAmenitiesDescription()
    {
        siteAmenities = new Hashtable();
        
        siteAmenities.put("BeautySalon", 
                new TextDescription(Hotel.hotelAmenity, Hotel.BeautyShop_salon));
        siteAmenities.put("CarRentalDesk", 
                new TextDescription(Hotel.hotelAmenity, Hotel.CarRentalDesk));
        siteAmenities.put("ConciergeDesk", 
                new TextDescription(Hotel.hotelAmenity, Hotel.ConciergeDesk));
        siteAmenities.put("Elevators", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Elevators));
        siteAmenities.put("Florist", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Florist));
        siteAmenities.put("ForeignCurrencyExchange", 
                new TextDescription(Hotel.hotelAmenity, Hotel.CurrencyExchange));
        siteAmenities.put("Laundry/ValetService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Laundry_ValetService));
        siteAmenities.put("LocalAreaTransportation", 
                new TextDescription(Hotel.hotelAmenity, 
                        Hotel.TransportationServices_localArea));
        siteAmenities.put("Multi-LingualStaff", 
                new TextDescription(Hotel.hotelAmenity, Hotel.MultilingualStaff));
        siteAmenities.put("RoomService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.RoomService));
        siteAmenities.put("SafetyDepositBox", 
                new TextDescription(Hotel.hotelAmenity, Hotel.SafeDepositBox));
        siteAmenities.put("ShoeShineStand", 
                new TextDescription(Hotel.hotelAmenity, Hotel.ShoeShineStand));
    }
    
    private static void createBusinessServicesDescription()
    {
        businessServices = new Hashtable();
        
        businessServices.put("Audio/VisualEquipmentRental", 
                new TextDescription(Hotel.businessServices, Hotel.AudioVisualEquipment));
        businessServices.put("MeetingRooms", 
                new TextDescription(Hotel.businessServices, Hotel.MeetingOrBoardRooms));
        businessServices.put("BusinessCenter", 
                new TextDescription(Hotel.businessServices, Hotel.On_siteBusinessCenter));
        businessServices.put("SecretarialService", 
                new TextDescription(Hotel.businessServices, Hotel.SecretarialServices));
        businessServices.put("CellularPhoneRental", 
                new TextDescription(Hotel.businessServices, Hotel.CellularPhoneRental));
    }
}
