package semfly.textmining;

import java.util.ArrayList;
import java.util.Hashtable;
import com.hp.hpl.jena.rdf.model.Resource;
import semfly.onto.jena.Hotel;
/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * Fake text miner. 
 */
public class MarriottTextMiner
{
    private static MarriottTextMiner instance;
    private static Hashtable roomAmenities;
    private static Hashtable guestRoomInfo; //TODO
    private static Hashtable recreationInfo;
    private static Hashtable petPolicyInfo;
    
    private static ArrayList notImportantProperties;
    
    static
    {
        notImportantProperties = new ArrayList();
        
        notImportantProperties.add("Pillows:down/feather");
        notImportantProperties.add("Pillows:foam");
        notImportantProperties.add("Rollawaybed");
        notImportantProperties.add("Cablechannel:CNN");
        notImportantProperties.add("Cablechannel:ESPN");
        notImportantProperties.add("Cablechannel:ESPN");
    }
    
    private MarriottTextMiner()
    {}
    
    public static MarriottTextMiner getInstance()
    {
        if (instance == null) 
        {
            instance = new MarriottTextMiner();
            createGuestRoomDescription();
            createRoomAmenitiesDescription();
            createRecreationInfoDescription();
            createPetPolicyDescription();
        }
        
        return instance;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getAmenityDescription(String text)
    {
        TextDescription desc = (TextDescription)roomAmenities.get(text);
       
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getGuestRoomDescription(String text)
    {
        TextDescription desc = (TextDescription)guestRoomInfo.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getGuestRoomInfo(String text)
    {
        TextDescription desc = (TextDescription)guestRoomInfo.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getRecreationDescription(String text)
    {
        TextDescription desc = (TextDescription)recreationInfo.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getPetsPolicyDescription(String text)
    {
        TextDescription desc = (TextDescription)petPolicyInfo.get(text);
        
        return desc;
    }
    
    private static void createRoomAmenitiesDescription()
    {
        roomAmenities = new Hashtable();
        
        roomAmenities.put("Airconditioning", 
                new TextDescription(Hotel.roomAmenity, Hotel.AirConditioning));
        roomAmenities.put("Alarmclock", 
                new TextDescription(Hotel.roomAmenity, Hotel.AlarmClock));
        roomAmenities.put("Bottledwater,forafee", 
                new TextDescription(Hotel.roomAmenity, Hotel.BottledWater));
        roomAmenities.put("Coffeemaker/teaservice", 
                new TextDescription(Hotel.roomAmenity, Hotel.Coffee_TeaMaker));
        roomAmenities.put("Crib", 
                new TextDescription(Hotel.roomAmenity, Hotel.Cribs));
        roomAmenities.put("Electricaladapters", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.ElectricalAdaptorsAvailable));
        roomAmenities.put("Individualclimatecontrol", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.AirConditioningIndividuallyControlledInRoom));
        roomAmenities.put("Ironandironingboard", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.Iron, Hotel.IroningBoard}));
        roomAmenities.put("Safe", 
                new TextDescription(Hotel.roomAmenity, Hotel.Safe));
        roomAmenities.put("Bathrobe", 
                new TextDescription(Hotel.roomAmenity, Hotel.Bathrobe));
        roomAmenities.put("Bathroomamenities", 
                new TextDescription(Hotel.roomAmenity, Hotel.BathroomAmenities));
        roomAmenities.put("Bathtubwithsprayjets", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.BathTubWithSprayJets));
        roomAmenities.put("Hairdryer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Hairdryer));
        roomAmenities.put("Cable/satelliteTV", 
                new TextDescription(Hotel.roomAmenity, Hotel.CableTelevision));
        roomAmenities.put("ColorTV", 
                new TextDescription(Hotel.roomAmenity, Hotel.ColorTelevision));
        roomAmenities.put("Mini-bar", 
                new TextDescription(Hotel.roomAmenity, Hotel.Minibar));
        roomAmenities.put("VCRplayer", 
                new TextDescription(Hotel.roomAmenity, Hotel.VCRPlayer));
        roomAmenities.put("Electricaloutlet:desklevel", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.DeskWithElectricalOutlet));
        roomAmenities.put("Phonefeature:voicemail", 
                new TextDescription(Hotel.roomAmenity, Hotel.VoiceMail));
        roomAmenities.put("Refrigerator", 
                new TextDescription(Hotel.roomAmenity, Hotel.Refrigerator));
        roomAmenities.put("Washer/dryer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Washer_dryer));
        roomAmenities.put("Wetbar", 
                new TextDescription(Hotel.roomAmenity, Hotel.WetBar));
        roomAmenities.put("Toaster", 
                new TextDescription(Hotel.roomAmenity, Hotel.Toaster));
        roomAmenities.put("Fax", 
                new TextDescription(Hotel.roomAmenity, Hotel.FaxMachine));
        roomAmenities.put("CDplayer", 
                new TextDescription(Hotel.roomAmenity, Hotel.CDplayer));
        roomAmenities.put("Dishwasher", 
                new TextDescription(Hotel.roomAmenity, Hotel.Dishwasher));
        roomAmenities.put("Hottub/Jacuzzi", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.Jacuzzi}));
        roomAmenities.put("Printer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Printer));
        roomAmenities.put("Fireplace", 
                new TextDescription(Hotel.roomAmenity, Hotel.Fireplace));
        roomAmenities.put("VCRmoviesforrent", 
                new TextDescription(Hotel.roomAmenity, Hotel.VCRRental));
        roomAmenities.put("Phonefeature:cordless", 
                new TextDescription(Hotel.roomAmenity, Hotel.CordlessPhone));
        roomAmenities.put("Separatetubandshower", 
                new TextDescription(Hotel.roomAmenity, Hotel.SeparateTubAndShower));
        roomAmenities.put("Movies/videos,pay-per-view", 
                new TextDescription(Hotel.roomAmenity, Hotel.PayPerViewMoviesOnTV));
        roomAmenities.put("Tableandchairs", 
                new TextDescription(Hotel.roomAmenity, Hotel.TablesAndChairs));
        roomAmenities.put("Internetbrowser/WebTV", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.InteractiveWebTV}));
        roomAmenities.put("Phonefeature:speakerphone", 
                new TextDescription(Hotel.roomAmenity, Hotel.SpeakerPhone));
        roomAmenities.put("Two-linephone", 
                new TextDescription(Hotel.roomAmenity, Hotel.Two_linePhone));
        roomAmenities.put("Microwaveoven", 
                new TextDescription(Hotel.roomAmenity, Hotel.Microwave));
        roomAmenities.put("Silverware", 
                new TextDescription(Hotel.roomAmenity, Hotel.Silverware_utensils));
        roomAmenities.put("Stove", 
                new TextDescription(Hotel.roomAmenity, Hotel.Stove));
        roomAmenities.put("Trouserpress", 
                new TextDescription(Hotel.roomAmenity, Hotel.Trouser_PantPress));
        roomAmenities.put("Bottledwater", 
                new TextDescription(Hotel.roomAmenity, Hotel.BottledWater));
        roomAmenities.put("Conventionaloven", 
                new TextDescription(Hotel.roomAmenity, Hotel.Oven));
        roomAmenities.put("Pots,pans,servingdishes", 
                new TextDescription(Hotel.roomAmenity, Hotel.PotsAndPans));
        roomAmenities.put("Waterpurificationsystem", 
                new TextDescription(Hotel.roomAmenity, Hotel.WaterPurificationSystem));
        roomAmenities.put("Refrigeratorwithicemaker", 
                new TextDescription(Hotel.roomAmenity, Hotel.RefrigeratorWithIceMaker));
        roomAmenities.put("Cablechannel:CNN", 
                new TextDescription(Hotel.roomAmenity, Hotel.CNNavailaible));
    }
    
    private static void createGuestRoomDescription()
    {
        guestRoomInfo = new Hashtable();
        
        guestRoomInfo.put("Airconditioning", 
                new TextDescription(Hotel.roomInfo, 
                        Hotel.airConditionedGuestRooms));
        
        guestRoomInfo.put("floors", 
                new TextDescription(Hotel.roomInfo, Hotel.floors));
        guestRoomInfo.put("rooms", 
                new TextDescription(Hotel.roomInfo, Hotel.totalRooms));
        guestRoomInfo.put("suites", 
                new TextDescription(Hotel.roomInfo, Hotel.suites));
        guestRoomInfo.put("TheRoomThatWorksguestrooms", 
                			new TextDescription(Hotel.roomInfo, Hotel.roomsThatWork));
        guestRoomInfo.put("totalRoomsAndSuites", 
    			new TextDescription(Hotel.roomInfo, Hotel.totalRoomsAndSuites));
    }
    
    private static void createRecreationInfoDescription()
    {
        recreationInfo = new Hashtable();
        
        recreationInfo.put("HeatedOutdoorPool,heated", 
                new TextDescription(Hotel.recreationService, Hotel.HeatedPool));
        recreationInfo.put("Jacuzzi", 
                new TextDescription(Hotel.recreationService, Hotel.Jacuzzi));
        recreationInfo.put("Whirlpool", 
                new TextDescription(Hotel.recreationService, Hotel.Whirlpool));
        recreationInfo.put("FitnessCenter", 
                new TextDescription(Hotel.recreationService, Hotel.FitnessCenterOnsite));
        recreationInfo.put("Bikingtrail", 
                new TextDescription(Hotel.recreationService, Hotel.BikeTrail));
        recreationInfo.put("Jogging/fitnesstrail", 
                new TextDescription(Hotel.recreationService, Hotel.JoggingTrail));
        recreationInfo.put("Sailing", 
                new TextDescription(Hotel.recreationService, Hotel.Sailing));
        recreationInfo.put("Sauna", 
                new TextDescription(Hotel.recreationService, Hotel.Sauna));
        recreationInfo.put("Squash", 
                new TextDescription(Hotel.recreationService, Hotel.SquashCourt));
        recreationInfo.put("Tennis", 
                new TextDescription(Hotel.recreationService, Hotel.Tennis));
        recreationInfo.put("Volleyball", 
                new TextDescription(Hotel.recreationService, Hotel.Volleyball));
        recreationInfo.put("Golf", 
                new TextDescription(Hotel.recreationService, Hotel.Golf));
        recreationInfo.put("Horsebackriding", 
                new TextDescription(Hotel.recreationService, Hotel.HorsebackRiding));
        recreationInfo.put("Jet-skiing", 
                new TextDescription(Hotel.recreationService, Hotel.Jet_ski));
        recreationInfo.put("Snowskiing", 
                new TextDescription(Hotel.recreationService, Hotel.SnowSkiing));
        recreationInfo.put("HealthClub", 
                new TextDescription(Hotel.recreationService, Hotel.HealthClub));
        recreationInfo.put("Kayaking", 
                new TextDescription(Hotel.recreationService, Hotel.Kayaking));
        recreationInfo.put("Scubadiving", 
                new TextDescription(Hotel.recreationService, Hotel.ScubaDiving));
        recreationInfo.put("Snorkeling", 
                new TextDescription(Hotel.recreationService, Hotel.Snorkeling));
        recreationInfo.put("Hiking", 
                new TextDescription(Hotel.recreationService, Hotel.HikingTrail));
        recreationInfo.put("Miniaturegolf", 
                new TextDescription(Hotel.recreationService, Hotel.MiniatureGolf));
        recreationInfo.put("Water-skiing", 
                new TextDescription(Hotel.recreationService, Hotel.Water_skiing));
        recreationInfo.put("OutdoorPool", 
                new TextDescription(Hotel.recreationService, Hotel.OutdoorPool));
        recreationInfo.put("Sportscourtonsite", 
                new TextDescription(Hotel.recreationService, Hotel.SportsCourtOnsite));
        recreationInfo.put("Beach", 
                new TextDescription(Hotel.recreationService, Hotel.Beach));
        recreationInfo.put("Surfing", 
                new TextDescription(Hotel.recreationService, Hotel.Surfing));
        recreationInfo.put("IndoorPool", 
                new TextDescription(Hotel.recreationService, Hotel.IndoorPool));
        recreationInfo.put("Mountainbiking,trail", 
                new TextDescription(Hotel.recreationService, Hotel.MountainBikingTrail));
        recreationInfo.put("Rockclimbing", 
                new TextDescription(Hotel.recreationService, Hotel.RockClimbing));
        recreationInfo.put("Hottub", 
                new TextDescription(Hotel.recreationService, Hotel.HotTub));
        recreationInfo.put("Fly-fishing", 
                new TextDescription(Hotel.recreationService, Hotel.FlyFishing));
        recreationInfo.put("Riverrafting", 
                new TextDescription(Hotel.recreationService, Hotel.RiverRafting));
        recreationInfo.put("Tabletennis", 
                new TextDescription(Hotel.recreationService, Hotel.TableTennis));
        recreationInfo.put("Pool", 
                new TextDescription(Hotel.recreationService, Hotel.Pool));
        recreationInfo.put("OutdoorPool,heated", 
                new TextDescription(Hotel.recreationService, Hotel.HeatedPool));
        recreationInfo.put("Gym", 
                new TextDescription(Hotel.recreationService, Hotel.Gym));
        recreationInfo.put("HotelGYM", 
                new TextDescription(Hotel.recreationService, Hotel.Gym));
        recreationInfo.put("IndoorPool", 
                new TextDescription(Hotel.recreationService, Hotel.IndoorPool));
        recreationInfo.put("HealthCentre", 
                new TextDescription(Hotel.recreationService, Hotel.HealthClub));
        recreationInfo.put("Hunting", 
                new TextDescription(Hotel.recreationService, Hotel.Hunting));
        recreationInfo.put("ExerciseRoom", 
                new TextDescription(Hotel.recreationService, Hotel.ExerciseGym));
        recreationInfo.put("Pool-SwimIn/Out,heated", 
                new TextDescription(Hotel.recreationService, 
                        new Resource[]{Hotel.IndoorPool, Hotel.OutdoorPool,
                        				Hotel.HeatedPool}));
        recreationInfo.put("Indoor/outdoorconnectingpool", 
                new TextDescription(Hotel.recreationService, 
                        new Resource[]{Hotel.IndoorPool, Hotel.OutdoorPool}));
        recreationInfo.put("FitnessCentre", 
                new TextDescription(Hotel.recreationService, Hotel.FitnessCenterOnsite));
        recreationInfo.put("On-SiteFitnessCentre", 
                new TextDescription(Hotel.recreationService, Hotel.FitnessCenterOnsite));
        recreationInfo.put("Naturepreserve,trail", 
                new TextDescription(Hotel.recreationService, Hotel.NaturePreserveTrail));
        recreationInfo.put("IslandGym", 
                new TextDescription(Hotel.recreationService, Hotel.Gym));
    }
    
    private static void createPetPolicyDescription()
    {
        petPolicyInfo = new Hashtable();
        
        petPolicyInfo.put("Petsnotallowed", 
                new TextDescription(Hotel.petsPolicy, Hotel.NoPetsAllowed));
    }
}
