package semfly.textmining;

import java.util.ArrayList;
import java.util.Hashtable;
import com.hp.hpl.jena.rdf.model.Resource;
import semfly.onto.jena.Hotel;
/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * Fake text miner. 
 */
public class SheratonTextMiner
{
    private static SheratonTextMiner instance;
    private static Hashtable roomAmenities;
    private static Hashtable guestRoomInfo; //TODO
    private static Hashtable servicesInfo;
    private static Hashtable petPolicyInfo;
    
    private static ArrayList notImportantProperties;
    
    static
    {
        notImportantProperties = new ArrayList();
    }
    
    private SheratonTextMiner()
    {}
    
    public static SheratonTextMiner getInstance()
    {
        if (instance == null) 
        {
            instance = new SheratonTextMiner();
            createGuestRoomDescription();
            createRoomAmenitiesDescription();
            createServicesInfoDescription();
        }
        
        return instance;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getAmenityDescription(String text)
    {
        TextDescription desc = (TextDescription)roomAmenities.get(text);
       
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getGuestRoomDescription(String text)
    {
        TextDescription desc = (TextDescription)guestRoomInfo.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getGuestRoomInfo(String text)
    {
        TextDescription desc = (TextDescription)guestRoomInfo.get(text);
        
        return desc;
    }
    
    /**
     * Returns an appropriate property(-ies) for the text given.
     */
    public TextDescription getServicesDescription(String text)
    {
        TextDescription desc = (TextDescription)servicesInfo.get(text);
        
        return desc;
    }
    
    private static void createRoomAmenitiesDescription()
    {
        roomAmenities = new Hashtable();
        
        roomAmenities.put("Air-ConditionedRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.AirConditioning));
        roomAmenities.put("AlarmClock", 
                new TextDescription(Hotel.roomAmenity, Hotel.AlarmClock));
        roomAmenities.put("Bottledwater,forafee", 
                new TextDescription(Hotel.roomAmenity, Hotel.BottledWater));
        roomAmenities.put("CoffeeMaker", 
                new TextDescription(Hotel.roomAmenity, Hotel.Coffee_TeaMaker));
        roomAmenities.put("CoffeeandTeaMaker", 
                new TextDescription(Hotel.roomAmenity, Hotel.Coffee_TeaMaker));
        roomAmenities.put("Cribs", 
                new TextDescription(Hotel.roomAmenity, Hotel.Cribs));
        roomAmenities.put("Electricaladapters", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.ElectricalAdaptorsAvailable));
        roomAmenities.put("IndividualClimateControl", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.AirConditioningIndividuallyControlledInRoom));
        roomAmenities.put("Ironandironingboard", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.Iron, Hotel.IroningBoard}));
        roomAmenities.put("In-RoomSafe", 
                new TextDescription(Hotel.roomAmenity, Hotel.Safe));
        roomAmenities.put("Bathrobes", 
                new TextDescription(Hotel.roomAmenity, Hotel.Bathrobe));
        roomAmenities.put("Bathroomamenities", 
                new TextDescription(Hotel.roomAmenity, Hotel.BathroomAmenities));
        roomAmenities.put("Bathtubwithsprayjets", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.BathTubWithSprayJets));
        roomAmenities.put("Hairdryer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Hairdryer));
        roomAmenities.put("CableChannels", 
                new TextDescription(Hotel.roomAmenity, Hotel.CableTelevision));
        roomAmenities.put("ColorTV", 
                new TextDescription(Hotel.roomAmenity, Hotel.ColorTelevision));
        roomAmenities.put("MiniBar", 
                new TextDescription(Hotel.roomAmenity, Hotel.Minibar));
        roomAmenities.put("VCRplayer", 
                new TextDescription(Hotel.roomAmenity, Hotel.VCRPlayer));
        roomAmenities.put("Electricaloutlet:desklevel", 
                new TextDescription(Hotel.roomAmenity, 
                        Hotel.DeskWithElectricalOutlet));
        roomAmenities.put("Phonefeature:voicemail", 
                new TextDescription(Hotel.roomAmenity, Hotel.VoiceMail));
        roomAmenities.put("Refrigerator", 
                new TextDescription(Hotel.roomAmenity, Hotel.Refrigerator));
        roomAmenities.put("Washer/dryer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Washer_dryer));
        roomAmenities.put("Wetbar", 
                new TextDescription(Hotel.roomAmenity, Hotel.WetBar));
        roomAmenities.put("Toaster", 
                new TextDescription(Hotel.roomAmenity, Hotel.Toaster));
        roomAmenities.put("FaxMachine", 
                new TextDescription(Hotel.roomAmenity, Hotel.FaxMachine));
        roomAmenities.put("CDplayer", 
                new TextDescription(Hotel.roomAmenity, Hotel.CDplayer));
        roomAmenities.put("Dishwasher", 
                new TextDescription(Hotel.roomAmenity, Hotel.Dishwasher));
        roomAmenities.put("JacuzziinRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.Jacuzzi));
        roomAmenities.put("Printer", 
                new TextDescription(Hotel.roomAmenity, Hotel.Printer));
        roomAmenities.put("Fireplace", 
                new TextDescription(Hotel.roomAmenity, Hotel.Fireplace));
        roomAmenities.put("VCRmoviesforrent", 
                new TextDescription(Hotel.roomAmenity, Hotel.VCRRental));
        roomAmenities.put("Phonefeature:cordless", 
                new TextDescription(Hotel.roomAmenity, Hotel.CordlessPhone));
        roomAmenities.put("Separatetubandshower", 
                new TextDescription(Hotel.roomAmenity, Hotel.SeparateTubAndShower));
        roomAmenities.put("Movies/videos,pay-per-view", 
                new TextDescription(Hotel.roomAmenity, Hotel.PayPerViewMoviesOnTV));
        roomAmenities.put("Tableandchairs", 
                new TextDescription(Hotel.roomAmenity, Hotel.TablesAndChairs));
        roomAmenities.put("Internetbrowser/WebTV", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.InteractiveWebTV}));
        roomAmenities.put("Phonefeature:speakerphone", 
                new TextDescription(Hotel.roomAmenity, Hotel.SpeakerPhone));
        roomAmenities.put("Dual-LineTelephone", 
                new TextDescription(Hotel.roomAmenity, Hotel.Two_linePhone));
        roomAmenities.put("MicrowaveOven", 
                new TextDescription(Hotel.roomAmenity, Hotel.Microwave));
        roomAmenities.put("Silverware", 
                new TextDescription(Hotel.roomAmenity, Hotel.Silverware_utensils));
        roomAmenities.put("Stove", 
                new TextDescription(Hotel.roomAmenity, Hotel.Stove));
        roomAmenities.put("Trouserpress", 
                new TextDescription(Hotel.roomAmenity, Hotel.Trouser_PantPress));
        roomAmenities.put("Bottledwater", 
                new TextDescription(Hotel.roomAmenity, Hotel.BottledWater));
        roomAmenities.put("Conventionaloven", 
                new TextDescription(Hotel.roomAmenity, Hotel.Oven));
        roomAmenities.put("Pots,pans,servingdishes", 
                new TextDescription(Hotel.roomAmenity, Hotel.PotsAndPans));
        roomAmenities.put("Waterpurificationsystem", 
                new TextDescription(Hotel.roomAmenity, Hotel.WaterPurificationSystem));
        roomAmenities.put("Refrigeratorwithicemaker", 
                new TextDescription(Hotel.roomAmenity, Hotel.RefrigeratorWithIceMaker));
        roomAmenities.put("Voicemail", 
                new TextDescription(Hotel.roomAmenity, Hotel.VoiceMail));
        roomAmenities.put("SofaBed", 
                new TextDescription(Hotel.roomAmenity, Hotel.SofaBed));
        roomAmenities.put("SmokeDetectorsinRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.SmokeDetectors));
        roomAmenities.put("FreeDailyNewspaper", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("Non-SmokingRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.nonsmokingRooms));
        roomAmenities.put("Wake-upServiceAvailable", 
                new TextDescription(Hotel.roomAmenity, Hotel.Wake_upCalls));
        roomAmenities.put("DataPort", 
                new TextDescription(Hotel.roomAmenity, Hotel.DataPort));
        roomAmenities.put("Fax/Copier/Printer", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.FaxMachine, Hotel.Printer}));
        roomAmenities.put("Iron/IroningBoard", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.Iron, Hotel.IroningBoard}));
        roomAmenities.put("WorkDesk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("FreeHighSpeedInternetAccessinAllGuestRooms", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.HighSpeedInternetConnection}));
        roomAmenities.put("Kitchenette", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("Television", 
                new TextDescription(Hotel.roomAmenity, Hotel.ColorTelevision));
        roomAmenities.put("CordlessTelephone", 
                new TextDescription(Hotel.roomAmenity, Hotel.CordlessPhone));
        roomAmenities.put("HighSpeedInternetAccessbyRequest(Charge)", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.HighSpeedInternetConnection}));
        roomAmenities.put("Desk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("BathroomTelephone", 
                new TextDescription(Hotel.roomAmenity, Hotel.BathroomTelephone));
        roomAmenities.put("InternationalDirectDialing", 
                new TextDescription(Hotel.roomAmenity, Hotel.InternationalDirectDialing));
        roomAmenities.put("Telephone", 
                new TextDescription(Hotel.roomAmenity, Hotel.Telephone));
        roomAmenities.put("FreeNewspaperonWeekdays", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("Radio/AlarmClock", 
                new TextDescription(Hotel.roomAmenity, Hotel.AlarmClock));
        roomAmenities.put("ConnectingRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.ConnectingRooms));
        roomAmenities.put("CDPlayer/Radio/AlarmClock", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.CDplayer, Hotel.AlarmClock}));
        roomAmenities.put("Bathrobes&Slippers", 
                new TextDescription(Hotel.roomAmenity, Hotel.Bathrobe));
        roomAmenities.put("DeluxeBathAmenities", 
                new TextDescription(Hotel.roomAmenity, Hotel.BathroomAmenities));
        roomAmenities.put("RoomwithFireplace", 
                new TextDescription(Hotel.roomAmenity, Hotel.Fireplace));
        roomAmenities.put("OversizedDesk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("FreeDailyNewspaper(National)", 
                new TextDescription(Hotel.roomAmenity, Hotel.Newspaper));
        roomAmenities.put("KnockLight(HearingImpaired)", 
                new TextDescription(Hotel.roomAmenity, Hotel.KnockLight));
        roomAmenities.put("Dual-LineSpeakerTelephone", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.Two_linePhone, Hotel.SpeakerPhone}));
        roomAmenities.put("RoomwithSittingArea", 
                new TextDescription(Hotel.roomAmenity, Hotel.SittingArea));
        roomAmenities.put("TurndownService", 
                new TextDescription(Hotel.roomAmenity, Hotel.TurnDownService));
        roomAmenities.put("WetBar", 
                new TextDescription(Hotel.roomAmenity, Hotel.WetBar));
        roomAmenities.put("FreeLocalCalls", 
                new TextDescription(Hotel.roomAmenity, Hotel.FreeLocalCalls));
        roomAmenities.put("OversizedDesk", 
                new TextDescription(Hotel.roomAmenity, Hotel.Desk));
        roomAmenities.put("HighSpeedInternetAccessinAllGuestRooms(Charge)", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.HighSpeedInternetConnection}));
        roomAmenities.put("Radio/AlarmClockonTV", 
                new TextDescription(Hotel.roomAmenity, Hotel.AlarmClock));
        roomAmenities.put("PersonalizedWake-UpService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.WakeupService));
        roomAmenities.put("TelevisionwithRemoteControl", 
                new TextDescription(Hotel.roomAmenity, Hotel.ColorTelevision));
        roomAmenities.put("TrouserPress", 
                new TextDescription(Hotel.roomAmenity, Hotel.Trouser_PantPress));
        roomAmenities.put("InternetServiceProvidedinAllGuestRooms(Charge)", 
                new TextDescription(Hotel.roomAmenity, Hotel.InternetAccess));
        roomAmenities.put("HandicapAccessibleRoom", 
                new TextDescription(Hotel.roomAmenity, Hotel.AccessibleRoom));
        roomAmenities.put("TelevisionwithInternetAccessandWirelessKeyboardinGuestRooms(Charge)", 
                new TextDescription(Hotel.roomAmenity, 
                        new Resource[]{Hotel.InternetAccess, Hotel.ColorTelevision}));
        roomAmenities.put("DirectDialing", 
                new TextDescription(Hotel.roomAmenity, Hotel.DirectDialPhoneNumber));
        roomAmenities.put("FullKitchen", 
                new TextDescription(Hotel.roomAmenity, Hotel.Kitchen));
        roomAmenities.put("OceanViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.OceanView));
        roomAmenities.put("CityViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.CityView));
        roomAmenities.put("MountainViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.MountainView));
        roomAmenities.put("PoolViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.PoolView));
        roomAmenities.put("BayViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.BayView));
        roomAmenities.put("RiverViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.RiverView));
        roomAmenities.put("SeaViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.WaterView));
        roomAmenities.put("LakeViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.LakeView));
        roomAmenities.put("LakeViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.WaterView));
        roomAmenities.put("River/CityViewRoom", 
                new TextDescription(Hotel.roomViewType, 
                        new Resource[]{Hotel.RiverView, Hotel.CityView}));
        roomAmenities.put("CourtyardViewRoom", 
                new TextDescription(Hotel.roomViewType, Hotel.CourtyardView));
    }
    
    private static void createGuestRoomDescription()
    {
        guestRoomInfo = new Hashtable();
        
        guestRoomInfo.put("Airconditioning", 
                new TextDescription(Hotel.roomInfo, 
                        Hotel.airConditionedGuestRooms));
        
        guestRoomInfo.put("floors", 
                new TextDescription(Hotel.roomInfo, Hotel.floors));
        guestRoomInfo.put("rooms", 
                new TextDescription(Hotel.roomInfo, Hotel.totalRooms));
        guestRoomInfo.put("suites", 
                new TextDescription(Hotel.roomInfo, Hotel.suites));
        guestRoomInfo.put("TheRoomThatWorksguestrooms", 
                			new TextDescription(Hotel.roomInfo, Hotel.roomsThatWork));
        guestRoomInfo.put("totalRoomsAndSuites", 
    			new TextDescription(Hotel.roomInfo, Hotel.totalRoomsAndSuites));
    }
    
    private static void createServicesInfoDescription()
    {
        servicesInfo = new Hashtable();
        
        servicesInfo.put("HeatedOutdoorPool,heated", 
                new TextDescription(Hotel.recreationService, Hotel.HeatedPool));
        servicesInfo.put("Jacuzzi", 
                new TextDescription(Hotel.recreationService, Hotel.Jacuzzi));
        servicesInfo.put("Whirlpool", 
                new TextDescription(Hotel.recreationService, Hotel.Whirlpool));
        servicesInfo.put("FitnessCenter", 
                new TextDescription(Hotel.recreationService, Hotel.FitnessCenterOnsite));
        servicesInfo.put("Bikingtrail", 
                new TextDescription(Hotel.recreationService, Hotel.BikeTrail));
        servicesInfo.put("Jogging/fitnesstrail", 
                new TextDescription(Hotel.recreationService, Hotel.JoggingTrail));
        servicesInfo.put("Sailing", 
                new TextDescription(Hotel.recreationService, Hotel.Sailing));
        servicesInfo.put("Sauna", 
                new TextDescription(Hotel.recreationService, Hotel.Sauna));
        servicesInfo.put("Squash", 
                new TextDescription(Hotel.recreationService, Hotel.SquashCourt));
        servicesInfo.put("Tennis", 
                new TextDescription(Hotel.recreationService, Hotel.Tennis));
        servicesInfo.put("Volleyball", 
                new TextDescription(Hotel.recreationService, Hotel.Volleyball));
        servicesInfo.put("Golf", 
                new TextDescription(Hotel.recreationService, Hotel.Golf));
        servicesInfo.put("Horsebackriding", 
                new TextDescription(Hotel.recreationService, Hotel.HorsebackRiding));
        servicesInfo.put("Jet-skiing", 
                new TextDescription(Hotel.recreationService, Hotel.Jet_ski));
        servicesInfo.put("Snowskiing", 
                new TextDescription(Hotel.recreationService, Hotel.SnowSkiing));
        servicesInfo.put("HealthClub", 
                new TextDescription(Hotel.recreationService, Hotel.HealthClub));
        servicesInfo.put("Kayaking", 
                new TextDescription(Hotel.recreationService, Hotel.Kayaking));
        servicesInfo.put("Scubadiving", 
                new TextDescription(Hotel.recreationService, Hotel.ScubaDiving));
        servicesInfo.put("Snorkeling", 
                new TextDescription(Hotel.recreationService, Hotel.Snorkeling));
        servicesInfo.put("Hiking", 
                new TextDescription(Hotel.recreationService, Hotel.HikingTrail));
        servicesInfo.put("Miniaturegolf", 
                new TextDescription(Hotel.recreationService, Hotel.MiniatureGolf));
        servicesInfo.put("Water-skiing", 
                new TextDescription(Hotel.recreationService, Hotel.Water_skiing));
        servicesInfo.put("OutdoorPool", 
                new TextDescription(Hotel.recreationService, Hotel.OutdoorPool));
        servicesInfo.put("Sportscourtonsite", 
                new TextDescription(Hotel.recreationService, Hotel.SportsCourtOnsite));
        servicesInfo.put("Beach", 
                new TextDescription(Hotel.recreationService, Hotel.Beach));
        servicesInfo.put("Surfing", 
                new TextDescription(Hotel.recreationService, Hotel.Surfing));
        servicesInfo.put("IndoorPool", 
                new TextDescription(Hotel.recreationService, Hotel.IndoorPool));
        servicesInfo.put("Mountainbiking,trail", 
                new TextDescription(Hotel.recreationService, Hotel.MountainBikingTrail));
        servicesInfo.put("Rockclimbing", 
                new TextDescription(Hotel.recreationService, Hotel.RockClimbing));
        servicesInfo.put("Hottub", 
                new TextDescription(Hotel.recreationService, Hotel.HotTub));
        servicesInfo.put("Fly-fishing", 
                new TextDescription(Hotel.recreationService, Hotel.FlyFishing));
        servicesInfo.put("Riverrafting", 
                new TextDescription(Hotel.recreationService, Hotel.RiverRafting));
        servicesInfo.put("Tabletennis", 
                new TextDescription(Hotel.recreationService, Hotel.TableTennis));
        servicesInfo.put("Pool", 
                new TextDescription(Hotel.recreationService, Hotel.Pool));
        servicesInfo.put("OutdoorPool,heated", 
                new TextDescription(Hotel.recreationService, Hotel.HeatedPool));
        servicesInfo.put("Gym", 
                new TextDescription(Hotel.recreationService, Hotel.Gym));
        servicesInfo.put("HotelGYM", 
                new TextDescription(Hotel.recreationService, Hotel.Gym));
        servicesInfo.put("IndoorPool", 
                new TextDescription(Hotel.recreationService, Hotel.IndoorPool));
        servicesInfo.put("HealthCentre", 
                new TextDescription(Hotel.recreationService, Hotel.HealthClub));
        servicesInfo.put("Hunting", 
                new TextDescription(Hotel.recreationService, Hotel.Hunting));
        servicesInfo.put("ExerciseRoom", 
                new TextDescription(Hotel.recreationService, Hotel.ExerciseGym));
        servicesInfo.put("Pool-SwimIn/Out,heated", 
                new TextDescription(Hotel.recreationService, 
                        new Resource[]{Hotel.IndoorPool, Hotel.OutdoorPool,
                        				Hotel.HeatedPool}));
        servicesInfo.put("Indoor/outdoorconnectingpool", 
                new TextDescription(Hotel.recreationService, 
                        new Resource[]{Hotel.IndoorPool, Hotel.OutdoorPool}));
        servicesInfo.put("FitnessCentre", 
                new TextDescription(Hotel.recreationService, Hotel.FitnessCenterOnsite));
        servicesInfo.put("On-SiteFitnessCentre", 
                new TextDescription(Hotel.recreationService, Hotel.FitnessCenterOnsite));
        servicesInfo.put("Naturepreserve,trail", 
                new TextDescription(Hotel.recreationService, Hotel.NaturePreserveTrail));
        servicesInfo.put("IslandGym", 
                new TextDescription(Hotel.recreationService, Hotel.Gym));
        servicesInfo.put("GolfCourseNearby", 
                new TextDescription(Hotel.recreationService, Hotel.GolfLocationOffsite));
        servicesInfo.put("JoggingPath", 
                new TextDescription(Hotel.recreationService, Hotel.JoggingTrail));
        //
        
        //--------------------------
        servicesInfo.put("IndoorHeatedPool", 
                new TextDescription(Hotel.hotelAmenity, Hotel.HeatedPool));
        servicesInfo.put("24-HourRoomService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.hour24RoomService));
        servicesInfo.put("IndoorWhirlpool", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Whirlpool));
        servicesInfo.put("CoveredParkingFacilities", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Parking));
        servicesInfo.put("FreeParkingFacilities", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Parking));
        servicesInfo.put("24-HourFrontDesk", 
                new TextDescription(Hotel.hotelAmenity, Hotel.hour24FrontDesk));
        servicesInfo.put("24-HourFrontDesk", 
                new TextDescription(Hotel.hotelAmenity, Hotel.hour24FrontDesk));
        servicesInfo.put("RoomService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.RoomService));
        servicesInfo.put("PersonalizedWake-UpService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.WakeupService));
        servicesInfo.put("Laundry/ValetService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Laundry_ValetService));
        servicesInfo.put("AirlineDesk", 
                new TextDescription(Hotel.hotelAmenity, Hotel.AirlineDesk));
        servicesInfo.put("Doorman", 
                new TextDescription(Hotel.hotelAmenity, Hotel.DoorMan));
        servicesInfo.put("CarRentalService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.CarRentalDesk));
        servicesInfo.put("BabysittingService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.BabySitting));
        servicesInfo.put("HairSalon", 
                new TextDescription(Hotel.hotelAmenity, Hotel.HairSalon));
        servicesInfo.put("LimousineService", 
                new TextDescription(Hotel.hotelAmenity, Hotel.LimousineService));
        servicesInfo.put("Bellstand/Porters", 
                new TextDescription(Hotel.hotelAmenity, Hotel.BellStaff_porter));
        servicesInfo.put("CurrencyExchange", 
                new TextDescription(Hotel.hotelAmenity, Hotel.CurrencyExchange));
        servicesInfo.put("Security", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Security));
        servicesInfo.put("ValetServiceandPaySelfParking", 
                new TextDescription(Hotel.hotelAmenity, Hotel.ValetParking));
        servicesInfo.put("ValetServiceandPaySelfParkingFacilities", 
                new TextDescription(Hotel.hotelAmenity, Hotel.ValetParking));
        servicesInfo.put("Casino", 
                new TextDescription(Hotel.hotelAmenity, Hotel.Casino));
       
        //business services
        servicesInfo.put("BusinessCenter/Services", 
                new TextDescription(Hotel.businessServices, Hotel.FullBusinessCenter));
        servicesInfo.put("SecretarialService", 
                new TextDescription(Hotel.businessServices, Hotel.SecretarialServices));
        servicesInfo.put("ComputerRental", 
                new TextDescription(Hotel.businessServices, Hotel.ComputerRental));
    }
    
    private static void createPetPolicyDescription()
    {
        petPolicyInfo = new Hashtable();
        
    }
}
